%% Modello geometrico semplificato
clear all
clc
close all
 
%import OpenSim libraries 
import org.opensim.modeling.*

% empty model creation
model = Model();
% set model name --> you will see it in the OpenSim GUI
model.setName('ScatolaCilindri3DOF')

% default unities are Newton for Force and meter for length

%% Parameters definition --> mass and bodies size
tot_mass=75; % subject's total mass [kg]
thorax_mass= 0.216*tot_mass; %[kg]
arm_mass= 0.028*tot_mass ; %[kg]
forearm_mass= 0.016*tot_mass;%[kg]
thorax_breadth= 0.25 ; %[m]
thorax_length= 0.3; %[m]
thorax_depth= 0.15; %[m]
arm_length= 0.33; %[m]
forearm_length= 0.27; %[m]

% zeros array creation for convenience
zeroVec3 = ArrayDouble.createVec3(0);

% set Gravity Force in the model (acceleration along y)
model.setGravity(Vec3(0,-9.80665,0));

%% ground body = thorax
% create a box that stand for thorax body and set thorax as ground body
thorax = model.getGroundBody();
% add geometry to thorax body
thorax.addDisplayGeometry('box.vtp');

% set thorax dimensions (depth, length and breadth) and transform initial 
% cube ('box.vtp') into rectangle
thorax_scale=thorax.updDisplayer();
thorax_scale.setScaleFactors(Vec3(thorax_depth, thorax_length, thorax_breadth));

% create an array for moments of inertia
Inertiavect = ArrayDouble(1, 6); % set array dimension (rows, columns)
% to set inertia moment I need to define vector position (Opensim start 
% numbering from 0) and quantity
Inertiavect.set(0,1); % 0= xx, 1= inertia moment value_xx
Inertiavect.set(1,1); % 1= yy, 1=inertia moment value_yy
Inertiavect.set(2,1); % 2= zz, 1=inertia moment value_zz
Inertiavect.set(3,0); % 3= xy, 0=inertia moment value_xy
Inertiavect.set(4,0); % 4= xz, 0=inertia moment value_xz
Inertiavect.set(5,0); % 5= yz, 0=inertia moment value_yz

%% cylinder = rigthArm body
rigthArm = Body(); % create rigthArm as a body
rigthArm.setName('RigthArm'); % set body name
rigthArm.setMass(arm_mass);   % set body mass previously defined
rigthArm.setMassCenter(zeroVec3); % set mass center position (at the center of body)
rigthArm.setInertia(Inertiavect); % set moment of inertia vector

% set a cylinder as rigthArm geometry
rigthArm.addDisplayGeometry('cylinder.vtp');
% scale body to have arm dimensions
rigthArm_scale=rigthArm.updDisplayer();
rigthArm_scale.setScaleFactors(Vec3(arm_length/15, arm_length, arm_length/15));

% create 3 DOF Joint between ground and rigthArm
locationInParentVec3 = ArrayDouble.createVec3([-thorax_depth/4, thorax_length/2, thorax_breadth/2]); % Parent's body frame joint position 
locationInChildVec3 = ArrayDouble.createVec3([0, arm_length/2, -arm_length/30]);  % Child's body frame joint position 

rigthArmToThorax = CustomJoint('rigthArmToThorax', thorax, locationInParentVec3, zeroVec3, rigthArm, locationInChildVec3, zeroVec3, false);
% set OrintationinParent and OrintationInChild as zeroVec3

shoulderCS= rigthArmToThorax.upd_CoordinateSet(); % create CoordinateSet (DOF)

shoulderCoord= Coordinate(); % create shoulderCoord as a coordinate
shoulderCoord.setName('r_shoulder_flex'); % set name
shoulderCoord.setDefaultValue(0);  % set default position (angle)
shoulderCoord.setDefaultSpeedValue(0); % set default velocity
shoulderCoord.setRangeMin(-1.57079); % set range [min;max] in radians
shoulderCoord.setRangeMax(3.14159);
shoulderCoord.setDefaultClamped(false); % clamped = limit coordinate value to range
shoulderCoord.setDefaultLocked(false);  % locked  = limit coordinate value to default
shoulderCS.cloneAndAppend(shoulderCoord); % add coordinate to Coordinate Set

shoulderCoord2= Coordinate();  % create shoulderCoord2 as a coordinate
shoulderCoord2.setName('r_shoulder_add');  % set name
shoulderCoord2.setDefaultValue(0);  % set default position (angle)
shoulderCoord2.setDefaultSpeedValue(0);  % set default velocity
shoulderCoord2.setRangeMin(-3.14159);   % set range [min;max] in radians
shoulderCoord2.setRangeMax(0);
shoulderCoord2.setDefaultClamped(false);  % clamped = limit coordinate value to range
shoulderCoord2.setDefaultLocked(false);  % locked  = limit coordinate value to default

shoulderCS.cloneAndAppend(shoulderCoord2); % add coordinate to Coordinate Set

shoulderCoord3= Coordinate(); % create shoulderCoord2 as a coordinate
shoulderCoord3.setName('r_shoulder_rot');  % set name
shoulderCoord3.setDefaultValue(0); % set default position (angle)
shoulderCoord3.setDefaultSpeedValue(0); % set default velocity
shoulderCoord3.setRangeMin(-1.57079); % set range [min;max] in radians
shoulderCoord3.setRangeMax(0.34906);
shoulderCoord3.setDefaultClamped(false); % clamped = limit coordinate value to range
shoulderCoord3.setDefaultLocked(false);  % locked  = limit coordinate value to default

shoulderCS.cloneAndAppend(shoulderCoord3);


% set for SpatialTranform axis value and DOF --> SpatialTransform are 3
% rotations and 3 translations
SpatialTransform = rigthArmToThorax.get_SpatialTransform();
% first set rotations, then traslations
% flexion = z rotation
rotation1 = SpatialTransform.get_rotation1(); % get rotation1
rotation1.set_coordinates(0,'r_shoulder_flex'); % set coordinate for rotation1
rotation1.set_axis(Vec3(0, 0, 1));  % set rotation axis (with CustomJoint I can change axis)
linear_function = LinearFunction(); % create linear transform function and set coefficients y=ax+b 
coefficents = ArrayDouble(1, 2); % set coefficient vector dimension
coefficents.set(0,1); % set a=1 (first coefficient)
coefficents.set(1,0); % set b=0 (second coefficient)
linear_function.setCoefficients(coefficents); % add coefficients to function
rotation1.set_function(linear_function); % add function to rotation1


% rotation = y rotation
rotation2 = SpatialTransform.get_rotation2();
rotation2.set_coordinates(0,'r_shoulder_rot');
rotation2.set_axis(Vec3(0, 1, 0));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation2.set_function(linear_function);

% abduction = x rotation
rotation3 = SpatialTransform.get_rotation3();
rotation3.set_coordinates(0,'r_shoulder_add');
rotation3.set_axis(Vec3(1, 0, 0));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation3.set_function(linear_function);

% shoulder doesn't have traslations so I set a constant transform function
% with zero value
translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

% add wrapping object to shoulder and elbow
% create wrap cylinder to rigth elbow 
TRI = WrapCylinder(); % create WrapCylinder 
TRI.setName('TRI'); % set name
TRI.setRadius(0.016); % set radius
TRI.setLength(0.05);  % set length
TRI.setQuadrantName('all'); % set quadrant wher to draw it 
TRI.connectToModelAndBody(model,rigthArm); % add cylinder to model and body
% these functions create a cylinder at the COM ofthe body, so I have to
% translate it to elbow
prop = TRI.getPropertyByName('translation'); % set translation
y_translation = PropertyHelper.getValueDouble(prop , 1); % set y translation(1)
PropertyHelper.setValueDouble(-0.165,prop, 1); % set translation value
BodyRef = rigthArm.getWrapObjectSet(); % add wrapCylinder to body
BodyRef.cloneAndAppend(TRI);

% create a sphere to rigth shoulder
TRI_BIClong = WrapSphere(); %create WrapSphere
TRI_BIClong.setName('TRI_BIClong'); %set name
prop = TRI_BIClong.getPropertyByName('radius'); % set property  = radius
radius = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.011,prop, 0); % set radius value
TRI_BIClong.setQuadrantName('all');  % set quadrant wher to draw it
TRI_BIClong.connectToModelAndBody(model,rigthArm); % add sphere to model and body
% these functions create a sphere at the COM of the body, so I have to
% translate it to shoulder
prop = TRI_BIClong.getPropertyByName('translation'); % set translation
y_translation = PropertyHelper.getValueDouble(prop , 1); % set y translation(1)
PropertyHelper.setValueDouble(0.165,prop, 1); % set translation value
BodyRef = rigthArm.getWrapObjectSet();  % add wraSphere to body
BodyRef.cloneAndAppend(TRI_BIClong);

% add rigthArm to model
model.addBody(rigthArm)


%% cylinder = lefthArm body
% I used the same procedure as rigthArm --> see it for comments
% I changed z value from negative to positive and vice versa for
% translations, x and y values for rotations
leftArm = Body();
leftArm.setName('LeftArm');
leftArm.setMass(arm_mass);
leftArm.setMassCenter(zeroVec3);
leftArm.setInertia(Inertiavect);

leftArm.addDisplayGeometry('cylinder.vtp');
leftArm_scale=leftArm.updDisplayer();
leftArm_scale.setScaleFactors(Vec3(arm_length/15, arm_length, arm_length/15));

% create a joint between lefthArm and ground
locationInParentVec3 = ArrayDouble.createVec3([-thorax_depth/4, thorax_length/2, -thorax_breadth/2]);
locationInChildVec3 = ArrayDouble.createVec3([0, arm_length/2, arm_length/30]);

leftArmToThorax = CustomJoint('leftArmToThorax', thorax, locationInParentVec3, zeroVec3, leftArm, locationInChildVec3, zeroVec3, false);

shoulderCS_l= leftArmToThorax.upd_CoordinateSet();
shoulderCoord_l = Coordinate();
shoulderCoord_l.setName('l_shoulder_flex');
shoulderCoord_l.setDefaultValue(0);
shoulderCoord_l.setDefaultSpeedValue(0);
shoulderCoord_l.setRangeMin(-1.57079);
shoulderCoord_l.setRangeMax(3.14159);
shoulderCoord_l.setDefaultClamped(false);
shoulderCoord_l.setDefaultLocked(false);

shoulderCS_l.cloneAndAppend(shoulderCoord_l);

shoulderCoord2_l = Coordinate();
shoulderCoord2_l.setName('l_shoulder_add');
shoulderCoord2_l.setDefaultValue(0);
shoulderCoord2_l.setDefaultSpeedValue(0);
shoulderCoord2_l.setRangeMin(-3.14159);
shoulderCoord2_l.setRangeMax(0);
shoulderCoord2_l.setDefaultClamped(false);
shoulderCoord2_l.setDefaultLocked(false);

shoulderCS_l.cloneAndAppend(shoulderCoord2_l);

shoulderCoord3_l = Coordinate();
shoulderCoord3_l.setName('l_shoulder_rot');
shoulderCoord3_l.setDefaultValue(0);
shoulderCoord3_l.setDefaultSpeedValue(0);
shoulderCoord3_l.setRangeMin(-1.57079);
shoulderCoord3_l.setRangeMax(0.349065);
shoulderCoord3_l.setDefaultClamped(false);
shoulderCoord3_l.setDefaultLocked(false);

shoulderCS_l.cloneAndAppend(shoulderCoord3_l);

SpatialTransform = leftArmToThorax.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_coordinates(0,'l_shoulder_flex');
rotation1.set_axis(Vec3(0, 0, 1));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation1.set_function(linear_function);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_coordinates(0,'l_shoulder_rot');
rotation2.set_axis(Vec3(0, -1, 0));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation2.set_function(linear_function);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_coordinates(0,'l_shoulder_add');
rotation3.set_axis(Vec3(-1, 0, 0));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation3.set_function(linear_function);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

% create Wrap objects
TRI_l = WrapCylinder();
TRI_l.setName('TRI_l');
TRI_l.setRadius(0.016);
TRI_l.setLength(0.05);
TRI_l.setQuadrantName('all');
TRI_l.connectToModelAndBody(model,leftArm);
prop = TRI_l.getPropertyByName('translation');
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.165,prop, 1);
BodyRef = leftArm.getWrapObjectSet();
BodyRef.cloneAndAppend(TRI_l);


TRI_BIClong_l = WrapSphere();
TRI_BIClong_l.setName('TRI_BIClong_l');
prop = TRI_BIClong_l.getPropertyByName('radius');
radius = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.011,prop, 0);
TRI_BIClong_l.setQuadrantName('all');
TRI_BIClong_l.connectToModelAndBody(model,rigthArm);
prop = TRI_BIClong_l.getPropertyByName('translation');
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(0.165,prop, 1);
BodyRef = leftArm.getWrapObjectSet();
BodyRef.cloneAndAppend(TRI_BIClong_l);

% add body to model
model.addBody(leftArm)

%% cylinder = rigthForearm
% I used the same procedure as rigthArm --> see it for comments
rigthForearm = Body();
rigthForearm.setName('rigthForearm');
rigthForearm.setMass(forearm_mass);
rigthForearm.setMassCenter(zeroVec3);
rigthForearm.setInertia(Inertiavect);

rigthForearm.addDisplayGeometry('cylinder.vtp');
rigthForearm_scale=rigthForearm.updDisplayer();
rigthForearm_scale.setScaleFactors(Vec3(forearm_length/15, forearm_length, forearm_length/15));

% create 2 DOF joint between rigthArm and rigthforearm
locationInParentVec3 = ArrayDouble.createVec3([0,  -arm_length/2,0]);
locationInChildVec3 = ArrayDouble.createVec3([0, forearm_length/2, 0]);

rigthForearmToArm = CustomJoint('rigthForearmToArm', rigthArm, locationInParentVec3, zeroVec3, rigthForearm, locationInChildVec3, zeroVec3, false);

elbowCS= rigthForearmToArm.upd_CoordinateSet();

elbowCoord= Coordinate();
elbowCoord.setName('r_elbow_flex');
elbowCoord.setDefaultValue(0); 
elbowCoord.setDefaultSpeedValue(0);
elbowCoord.setRangeMin(0);
elbowCoord.setRangeMax(2.26892803);
elbowCoord.setDefaultClamped(false);
elbowCoord.setDefaultLocked(false);

elbowCS.cloneAndAppend(elbowCoord);

elbowCoord2= Coordinate(); 
elbowCoord2.setName('r_elbow_prosup');
elbowCoord2.setDefaultValue(0);
elbowCoord2.setDefaultSpeedValue(0);
elbowCoord2.setRangeMin(-1.570796326795); 
elbowCoord2.setRangeMax(1.570796326795);
elbowCoord2.setDefaultClamped(false);
elbowCoord2.setDefaultLocked(false);

elbowCS.cloneAndAppend(elbowCoord2);


SpatialTransform = rigthForearmToArm.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_coordinates(0,'r_elbow_flex');
rotation1.set_axis(Vec3(0, 0, 1));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation1.set_function(linear_function);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_coordinates(0,'r_elbow_prosup');
rotation2.set_axis(Vec3(0, 1, 0));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation2.set_function(linear_function);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
rotation3.set_function(constant);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

% add body to model
model.addBody(rigthForearm)


%% cylinder = leftForearm
% I used the same procedure as rigthArm --> see it for comments
% I changed z translation and x and y rotations from rigthForearm
leftForearm = Body();
leftForearm.setName('leftForearm');
leftForearm.setMass(forearm_mass);
leftForearm.setMassCenter(zeroVec3);
leftForearm.setInertia(Inertiavect);

leftForearm.addDisplayGeometry('cylinder.vtp');
leftForearm_scale=leftForearm.updDisplayer();
leftForearm_scale.setScaleFactors(Vec3(forearm_length/15, forearm_length, forearm_length/15));

% create 2 DOF joint between leftArm and leftForearm
locationInParentVec3 = ArrayDouble.createVec3([0,  -arm_length/2,0]);
locationInChildVec3 = ArrayDouble.createVec3([0, forearm_length/2, 0]);

leftForearmToArm = CustomJoint('leftForearmToArm', leftArm, locationInParentVec3, zeroVec3, leftForearm, locationInChildVec3, zeroVec3, false);

elbowCS_l= leftForearmToArm.upd_CoordinateSet();
elbowCoord_l= Coordinate();
elbowCoord_l.setName('l_elbow_flex');
elbowCoord_l.setDefaultValue(0);
elbowCoord_l.setDefaultSpeedValue(0);
elbowCoord_l.setRangeMin(0);
elbowCoord_l.setRangeMax(2.26892803);
elbowCoord_l.setDefaultClamped(false);
elbowCoord_l.setDefaultLocked(false);

elbowCS_l.cloneAndAppend(elbowCoord_l);

elbowCoord2_l= Coordinate();
elbowCoord2_l.setName('l_elbow_prosup');
elbowCoord2_l.setDefaultValue(0);
elbowCoord2_l.setDefaultSpeedValue(0);
elbowCoord2_l.setRangeMin(-1.570796326795);
elbowCoord2_l.setRangeMax(1.570796326795);
elbowCoord2_l.setDefaultClamped(false);
elbowCoord2_l.setDefaultLocked(false);

elbowCS_l.cloneAndAppend(elbowCoord2_l);

SpatialTransform = leftForearmToArm.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_coordinates(0,'l_elbow_flex');
rotation1.set_axis(Vec3(0, 0, 1));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation1.set_function(linear_function);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_coordinates(0,'l_elbow_prosup');
rotation2.set_axis(Vec3(0, -1, 0));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation2.set_function(linear_function);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_axis(Vec3(-1, 0, 0));
constant = Constant();
constant.setValue(0);
rotation3.set_function(constant);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

% add body to model
model.addBody(leftForearm)

%% rigth arm muscles
% Set muscle parameters TRIlong
maxIsometricForce  = 798.5; %set max isometric force [N]
optimalFiberLength = 0.134;  % set muscle fiber length [m]
tendonSlackLength  = 0.143;  % set tendon length [m]
pennationAngle 	   = 0.20943951; % set pennation angle in radians 

% create long tricipite muscle
TRIlong = Thelen2003Muscle(); % set muscle type
TRIlong.setName('TRIlong')  % set name
TRIlong.setMaxIsometricForce(maxIsometricForce) % set max isometric force to model
TRIlong.setOptimalFiberLength(optimalFiberLength) % set muscle fiber length to model
TRIlong.setTendonSlackLength(tendonSlackLength);  %  set tendon length to model
TRIlong.setPennationAngleAtOptimalFiberLength(pennationAngle) %  set pennation angle to model

% create path for muscle with fixed point
% insert point name, body and x,y,z coordinates
TRIlong.addNewPathPoint('TRIlong-P1', thorax, ArrayDouble.createVec3([-0.075,0.12,0.125]));
TRIlong.addNewPathPoint('TRIlong-P2', rigthArm, ArrayDouble.createVec3([-0.0275, 0.04125,0]));
TRIlong.addNewPathPoint('TRIlong-P3', rigthArm, ArrayDouble.createVec3([-0.0275, -0.11,0]));
TRIlong.addNewPathPoint('TRIlong-P4', rigthArm, ArrayDouble.createVec3([-0.019, -0.1485,0]));
TRIlong.addNewPathPoint('TRIlong-P5', rigthForearm, ArrayDouble.createVec3([-0.019, 0.135,0]));

% create muscle path over WrapObject
newWrapObj=PathWrap();
newWrapObj.setName('TRI');    % set PathWrap name
newWrapObj.setWrapObject(TRI); % set WrapObject
geoPath=TRIlong.getGeometryPath();  % add path to muscle
wrapSet=geoPath.getWrapSet();         
wrapSet.cloneAndAppend(newWrapObj);   % add wrap just created to PathWrap

model.addForce(TRIlong) % add muscle to model


% Set muscle parameters TRIlat
% for comments see TRIlong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.098;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRIlat = Thelen2003Muscle();
TRIlat.setName('TRIlat')
TRIlat.setMaxIsometricForce(maxIsometricForce)
TRIlat.setOptimalFiberLength(optimalFiberLength)
TRIlat.setTendonSlackLength(tendonSlackLength);
TRIlat.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRIlat
TRIlat.addNewPathPoint('TRIlat-P1', rigthArm, ArrayDouble.createVec3([-0.011,0.036667,0.0055]));
TRIlat.addNewPathPoint('TRIlat-P2', rigthArm, ArrayDouble.createVec3([-0.0275, 0, 0.0055]));
TRIlat.addNewPathPoint('TRIlat-P3', rigthArm, ArrayDouble.createVec3([-0.0275, -0.11,0]));
TRIlat.addNewPathPoint('TRIlat-P4', rigthArm, ArrayDouble.createVec3([-0.019, -0.1485,0]));
TRIlat.addNewPathPoint('TRIlat-P5', rigthForearm, ArrayDouble.createVec3([-0.019, 0.135,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI');   
newWrapObj.setWrapObject(TRI);

geoPath=TRIlat.getGeometryPath(); 
wrapSet=geoPath.getWrapSet();           
wrapSet.cloneAndAppend(newWrapObj);   

model.addForce(TRIlat)


% Set muscle parameters TRImed
% for comments see TRIlong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.098;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRImed = Thelen2003Muscle();
TRImed.setName('TRImed')
TRImed.setMaxIsometricForce(maxIsometricForce)
TRImed.setOptimalFiberLength(optimalFiberLength)
TRImed.setTendonSlackLength(tendonSlackLength);
TRImed.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRImed
TRImed.addNewPathPoint('TRImed-P1', rigthArm, ArrayDouble.createVec3([-0.011, 0.033, -0.0055]));
TRImed.addNewPathPoint('TRImed-P2', rigthArm, ArrayDouble.createVec3([-0.0275, 0,-0.0055]));
TRImed.addNewPathPoint('TRImed-P3', rigthArm, ArrayDouble.createVec3([-0.0275, -0.11,0]));
TRImed.addNewPathPoint('TRImed-P4', rigthArm, ArrayDouble.createVec3([-0.019, -0.1485,0]));
TRImed.addNewPathPoint('TRImed-P5', rigthForearm, ArrayDouble.createVec3([-0.019, 0.135,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI'); 
newWrapObj.setWrapObject(TRI);

geoPath=TRImed.getGeometryPath();
wrapSet=geoPath.getWrapSet();         
wrapSet.cloneAndAppend(newWrapObj);  

model.addForce(TRImed)


% Set muscle parameters BIClong
% for comments see TRIlong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1157;
tendonSlackLength  = 0.2723;
pennationAngle 	   = 0;

% Create new muscle
BIClong = Thelen2003Muscle();
BIClong.setName('BIClong')
BIClong.setMaxIsometricForce(maxIsometricForce)
BIClong.setOptimalFiberLength(optimalFiberLength)
BIClong.setTendonSlackLength(tendonSlackLength);
BIClong.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for BIClong
BIClong.addNewPathPoint('BIClong-P1', thorax, ArrayDouble.createVec3([-0.05625,0.14,0.125]));
BIClong.addNewPathPoint('BIClong-P2', rigthArm, ArrayDouble.createVec3([0, 0.176,0]));
BIClong.addNewPathPoint('BIClong-P3', rigthArm, ArrayDouble.createVec3([0.011, 0.165,0]));
BIClong.addNewPathPoint('BIClong-P4', rigthArm, ArrayDouble.createVec3([0.011, 0.124,0]));
BIClong.addNewPathPoint('BIClong-P5', rigthArm, ArrayDouble.createVec3([0.011, 0.105,0]));
BIClong.addNewPathPoint('BIClong-P6', rigthArm, ArrayDouble.createVec3([0.013, 0.07125,0]));
BIClong.addNewPathPoint('BIClong-P7', rigthArm, ArrayDouble.createVec3([0.02, 0.04125,0]));
BIClong.addNewPathPoint('BIClong-P8', rigthArm, ArrayDouble.createVec3([0.022, -0.04125,0]));
BIClong.addNewPathPoint('BIClong-P9', rigthForearm, ArrayDouble.createVec3([0.009, 0.0775,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI_BIClong');  
newWrapObj.setWrapObject(TRI_BIClong);

geoPath=BIClong.getGeometryPath(); 
wrapSet=geoPath.getWrapSet();          
wrapSet.cloneAndAppend(newWrapObj);  

model.addForce(BIClong)


% Set muscle parameters BICshort
% for comments see TRIlong
maxIsometricForce  = 435.56;
optimalFiberLength = 0.1321;
tendonSlackLength  = 0.1923;
pennationAngle 	   = 0;

% Create new muscle
BICshort = Thelen2003Muscle();
BICshort.setName('BICshort')
BICshort.setMaxIsometricForce(maxIsometricForce)
BICshort.setOptimalFiberLength(optimalFiberLength)
BICshort.setTendonSlackLength(tendonSlackLength);
BICshort.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for BICshort
BICshort.addNewPathPoint('BICshort-P1', thorax, ArrayDouble.createVec3([-0.005, 0.124, 0.125]));
BICshort.addNewPathPoint('BICshort-P2', thorax, ArrayDouble.createVec3([-0.02, 0.105, 0.125]));
BICshort.addNewPathPoint('BICshort-P3', rigthArm, ArrayDouble.createVec3([0.013, 0.07125,-0.0055]));
BICshort.addNewPathPoint('BICshort-P4', rigthArm, ArrayDouble.createVec3([0.02, 0.04125,-0.0055]));
BICshort.addNewPathPoint('BICshort-P5', rigthArm, ArrayDouble.createVec3([0.022, -0.04125,0]));
BICshort.addNewPathPoint('BICshort-P6', rigthForearm, ArrayDouble.createVec3([0.009, 0.0775,0]));


model.addForce(BICshort)


% Set muscle parameters BRA
% for comments see TRIlong
maxIsometricForce  = 987.26;
optimalFiberLength = 0.0858;
tendonSlackLength  = 0.0535;
pennationAngle 	   = 0;

% Create new muscle
BRA = Thelen2003Muscle();
BRA.setName('BRA')
BRA.setMaxIsometricForce(maxIsometricForce)
BRA.setOptimalFiberLength(optimalFiberLength)
BRA.setTendonSlackLength(tendonSlackLength);
BRA.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRImed
BRA.addNewPathPoint('BRA-P1', rigthArm, ArrayDouble.createVec3([0.011, -0.05, 0]));
BRA.addNewPathPoint('BRA-P2', rigthForearm, ArrayDouble.createVec3([0.011, 0.106, -0.011]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI');   
newWrapObj.setWrapObject(TRI);

geoPath=BRA.getGeometryPath();  
wrapSet=geoPath.getWrapSet();         
wrapSet.cloneAndAppend(newWrapObj);  


model.addForce(BRA)


%% left arm muscles
% Set muscle parameters TRIlong_l
% for comments see TRIlong
% I changed z sign from rigth muscles
maxIsometricForce  = 798.5;
optimalFiberLength = 0.134;
tendonSlackLength  = 0.143;
pennationAngle 	   = 0.20943951;

% Create new muscle
TRIlong_l = Thelen2003Muscle();
TRIlong_l.setName('TRIlong_l')
TRIlong_l.setMaxIsometricForce(maxIsometricForce)
TRIlong_l.setOptimalFiberLength(optimalFiberLength)
TRIlong_l.setTendonSlackLength(tendonSlackLength);
TRIlong_l.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRIlong_l
TRIlong_l.addNewPathPoint('TRIlong_l-P1', thorax, ArrayDouble.createVec3([-0.075,0.12,-0.125]));
TRIlong_l.addNewPathPoint('TRIlong_l-P2', leftArm, ArrayDouble.createVec3([-0.0275, 0.04125,0]));
TRIlong_l.addNewPathPoint('TRIlong_l-P3', leftArm, ArrayDouble.createVec3([-0.0275, -0.11,0]));
TRIlong_l.addNewPathPoint('TRIlong_l-P4', leftArm, ArrayDouble.createVec3([-0.019, -0.1485,0]));
TRIlong_l.addNewPathPoint('TRIlong_l-P5', leftForearm, ArrayDouble.createVec3([-0.019, 0.135,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI_l'); 
newWrapObj.setWrapObject(TRI_l);

geoPath=TRIlong_l.getGeometryPath();  
wrapSet=geoPath.getWrapSet();       
wrapSet.cloneAndAppend(newWrapObj);   

model.addForce(TRIlong_l)


% Set muscle parameters TRIlat_l
% for comments see TRIlong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.098;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRIlat_l = Thelen2003Muscle();
TRIlat_l.setName('TRIlat_l')
TRIlat_l.setMaxIsometricForce(maxIsometricForce)
TRIlat_l.setOptimalFiberLength(optimalFiberLength)
TRIlat_l.setTendonSlackLength(tendonSlackLength);
TRIlat_l.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRIlat
TRIlat_l.addNewPathPoint('TRIlat_l-P1', leftArm, ArrayDouble.createVec3([-0.011,0.036667,-0.0055]));
TRIlat_l.addNewPathPoint('TRIlat_l-P2', leftArm, ArrayDouble.createVec3([-0.0275, 0, -0.0055]));
TRIlat_l.addNewPathPoint('TRIlat_l-P3', leftArm, ArrayDouble.createVec3([-0.0275, -0.11,0]));
TRIlat_l.addNewPathPoint('TRIlat_l-P4', leftArm, ArrayDouble.createVec3([-0.019, -0.1485,0]));
TRIlat_l.addNewPathPoint('TRIlat_l-P5', leftForearm, ArrayDouble.createVec3([-0.019, 0.135,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI_l');  
newWrapObj.setWrapObject(TRI_l);

geoPath=TRIlat_l.getGeometryPath(); 
wrapSet=geoPath.getWrapSet();           
wrapSet.cloneAndAppend(newWrapObj);   

model.addForce(TRIlat_l)


% Set muscle parameters TRImed_l
% for comments see TRIlong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.098;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRImed_l = Thelen2003Muscle();
TRImed_l.setName('TRImed_l')
TRImed_l.setMaxIsometricForce(maxIsometricForce)
TRImed_l.setOptimalFiberLength(optimalFiberLength)
TRImed_l.setTendonSlackLength(tendonSlackLength);
TRImed_l.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRImed
TRImed_l.addNewPathPoint('TRImed_l-P1', leftArm, ArrayDouble.createVec3([-0.011, 0.033, 0.0055]));
TRImed_l.addNewPathPoint('TRImed_l-P2', leftArm, ArrayDouble.createVec3([-0.0275, 0,0.0055]));
TRImed_l.addNewPathPoint('TRImed_l-P3', leftArm, ArrayDouble.createVec3([-0.0275, -0.11,0]));
TRImed_l.addNewPathPoint('TRImed_l-P4', leftArm, ArrayDouble.createVec3([-0.019, -0.1485,0]));
TRImed_l.addNewPathPoint('TRImed_l-P5', leftForearm, ArrayDouble.createVec3([-0.019, 0.135,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI_l');   
newWrapObj.setWrapObject(TRI_l);

geoPath=TRImed_l.getGeometryPath(); 
wrapSet=geoPath.getWrapSet();          
wrapSet.cloneAndAppend(newWrapObj);  

model.addForce(TRImed_l)


% Set muscle parameters BIClong_l
% for comments see TRIlong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1157;
tendonSlackLength  = 0.2723;
pennationAngle 	   = 0;

% Create new muscle
BIClong_l = Thelen2003Muscle();
BIClong_l.setName('BIClong_l')
BIClong_l.setMaxIsometricForce(maxIsometricForce)
BIClong_l.setOptimalFiberLength(optimalFiberLength)
BIClong_l.setTendonSlackLength(tendonSlackLength);
BIClong_l.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for BIClong
BIClong_l.addNewPathPoint('BIClong_l-P1', thorax, ArrayDouble.createVec3([-0.05625,0.14,-0.125]));
BIClong_l.addNewPathPoint('BIClong_l-P2', leftArm, ArrayDouble.createVec3([0, 0.176,0]));
BIClong_l.addNewPathPoint('BIClong_l-P3', leftArm, ArrayDouble.createVec3([0.011, 0.165,0]));
BIClong_l.addNewPathPoint('BIClong_l-P4', leftArm, ArrayDouble.createVec3([0.011, 0.124,0]));
BIClong_l.addNewPathPoint('BIClong_l-P5', leftArm, ArrayDouble.createVec3([0.011, 0.105,0]));
BIClong_l.addNewPathPoint('BIClong_l-P6', leftArm, ArrayDouble.createVec3([0.013, 0.07125,0]));
BIClong_l.addNewPathPoint('BIClong_l-P7', leftArm, ArrayDouble.createVec3([0.02, 0.04125,0]));
BIClong_l.addNewPathPoint('BIClong_l-P8', leftArm, ArrayDouble.createVec3([0.022, -0.04125,0]));
BIClong_l.addNewPathPoint('BIClong_l-P9', leftForearm, ArrayDouble.createVec3([0.009, 0.0775,0]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI_BIClong_l');   
newWrapObj.setWrapObject(TRI_BIClong_l);

geoPath=BIClong_l.getGeometryPath();  
wrapSet=geoPath.getWrapSet();           
wrapSet.cloneAndAppend(newWrapObj);   

model.addForce(BIClong_l)


% Set muscle parameters BICshort_l
% for comments see TRIlong
maxIsometricForce  = 435.56;
optimalFiberLength = 0.1321;
tendonSlackLength  = 0.1923;
pennationAngle 	   = 0;

% Create new muscle
BICshort_l = Thelen2003Muscle();
BICshort_l.setName('BICshort_l')
BICshort_l.setMaxIsometricForce(maxIsometricForce)
BICshort_l.setOptimalFiberLength(optimalFiberLength)
BICshort_l.setTendonSlackLength(tendonSlackLength);
BICshort_l.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for BICshort
BICshort_l.addNewPathPoint('BICshort_l-P1', thorax, ArrayDouble.createVec3([-0.005, 0.124, -0.125]));
BICshort_l.addNewPathPoint('BICshort_l-P2', thorax, ArrayDouble.createVec3([-0.02, 0.105, -0.125]));
BICshort_l.addNewPathPoint('BICshort_l-P3', leftArm, ArrayDouble.createVec3([0.013, 0.07125,0.0055]));
BICshort_l.addNewPathPoint('BICshort_l-P4', leftArm, ArrayDouble.createVec3([0.02, 0.04125,0.0055]));
BICshort_l.addNewPathPoint('BICshort_l-P5', leftArm, ArrayDouble.createVec3([0.022, -0.04125,0]));
BICshort_l.addNewPathPoint('BICshort_l-P6', leftForearm, ArrayDouble.createVec3([0.009, 0.0775,0]));

model.addForce(BICshort_l)


% Set muscle parameters BRA_l
% for comments see TRIlong
maxIsometricForce  = 987.26;
optimalFiberLength = 0.0858;
tendonSlackLength  = 0.0535;
pennationAngle 	   = 0;

% Create new muscle
BRA_l = Thelen2003Muscle();
BRA_l.setName('BRA_l')
BRA_l.setMaxIsometricForce(maxIsometricForce)
BRA_l.setOptimalFiberLength(optimalFiberLength)
BRA_l.setTendonSlackLength(tendonSlackLength);
BRA_l.setPennationAngleAtOptimalFiberLength(pennationAngle)

% Path for TRImed
BRA_l.addNewPathPoint('BRA_l-P1', leftArm, ArrayDouble.createVec3([0.011, -0.05, 0]));
BRA_l.addNewPathPoint('BRA_l-P2', leftForearm, ArrayDouble.createVec3([0.011, 0.106, 0.011]));

%Create the Muscle Wrap Object
newWrapObj=PathWrap();
newWrapObj.setName('TRI_l');   
newWrapObj.setWrapObject(TRI_l);

geoPath=BRA_l.getGeometryPath(); 
wrapSet=geoPath.getWrapSet(); 
wrapSet.cloneAndAppend(newWrapObj);  

model.addForce(BRA_l)

%% save model as name.osim
model.print('scatola_cilindri_3DOF.osim');


