%% MODELLO 'Arm26_bilaterale'

% FOR COMMENTS SEE 'SCATOLA-CILINDRI' MATLAB SCRIPT
clear all
clc
close all
 
%import OpenSim libraries 
import org.opensim.modeling.*

% empty model creation
model = Model();
% set model name --> you will see it in the OpenSim GUI
model.setName('amr26_specchiato')

% zeros array creation for convenience
zeroVec3 = ArrayDouble.createVec3(0);

% set Gravity Force in the model (acceleration along y)
model.setGravity(Vec3(0,-9.80665,0));

% create an array for moments of inertia
Inertiavect = ArrayDouble(1, 6); % set array dimension (rows, columns)
% to set inertia moment I need to define vector position (Opensim start 
% numbering from 0) and quantity
Inertiavect.set(0,0); % 0= xx, 0= inertia moment value_xx
Inertiavect.set(1,0); % 1= yy, 0=inertia moment value_yy
Inertiavect.set(2,0); % 2= zz, 0=inertia moment value_zz
Inertiavect.set(3,0); % 3= xy, 0=inertia moment value_xy
Inertiavect.set(4,0); % 4= xz, 0=inertia moment value_xz
Inertiavect.set(5,0); % 5= yz, 0=inertia moment value_yz


%% ground body = thorax body
ground = model.getGroundBody(); %create thorax as ground
ground.setName('ground');  %set body name
ground.setMass(0); % set body mass
ground.setMassCenter(zeroVec3); %set COM vector
ground.setInertia(Inertiavect);  %set inertia vector

ground.addDisplayGeometry('thorax.vtp');  % add geometry


% create WrapCylinder to rigth shoulder
TRIlongglen = WrapCylinder();
TRIlongglen.setName('TRIlongglen'); %set name
TRIlongglen.setRadius(0.003);  % set radius
TRIlongglen.setLength(0.03); % set length
TRIlongglen.setQuadrantName('x');  % set quadrant to draw it
TRIlongglen.connectToModelAndBody(model,ground);
% these functions create a cylinder at the COM of the body in the 
%orientation of the body axis, so I have to translate it and rotate it
xyz_body_rotation = TRIlongglen.getPropertyByName('xyz_body_rotation'); % set rotation
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);  % x rotation
PropertyHelper.setValueDouble(1.37532,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);  % y rotation
PropertyHelper.setValueDouble(-0.294612,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2); % z rotation
PropertyHelper.setValueDouble(2.43596,xyz_body_rotation, 2);

prop = TRIlongglen.getPropertyByName('translation'); % set traslation
x_translation = PropertyHelper.getValueDouble(prop , 0); % x translation
PropertyHelper.setValueDouble(-0.043905,prop, 0);
y_translation = PropertyHelper.getValueDouble(prop , 1); % y translation
PropertyHelper.setValueDouble(-0.00395,prop, 1);
z_translation = PropertyHelper.getValueDouble(prop , 2);  % z translation
PropertyHelper.setValueDouble(0.1478,prop, 2);

BodyRef = ground.getWrapObjectSet(); % add object to body
BodyRef.cloneAndAppend(TRIlongglen);  


% create a WrapCylinder to left shoulder
% same as WrapCylinder to rigth shoulder but change z translation sign and
% x, y rotation sign
TRIlongglen_l = WrapCylinder();
TRIlongglen_l.setName('TRIlongglen_l');
TRIlongglen_l.setRadius(0.003);
TRIlongglen_l.setLength(0.03);
TRIlongglen_l.setQuadrantName('x');
TRIlongglen_l.connectToModelAndBody(model,ground);
% set rotation
xyz_body_rotation = TRIlongglen_l.getPropertyByName('xyz_body_rotation');  % x rotation
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(-1.37532,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1); % y rotation
PropertyHelper.setValueDouble(0.294612,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2); % z rotation
PropertyHelper.setValueDouble(2.43596,xyz_body_rotation, 2);
% set translation
prop = TRIlongglen_l.getPropertyByName('translation'); 
x_translation = PropertyHelper.getValueDouble(prop , 0); % x translation
PropertyHelper.setValueDouble(-0.043905,prop, 0);
y_translation = PropertyHelper.getValueDouble(prop , 1);  %  y translation
PropertyHelper.setValueDouble(-0.00395,prop, 1);
z_translation = PropertyHelper.getValueDouble(prop , 2); %  z translation
PropertyHelper.setValueDouble(-0.1478,prop, 2);

BodyRef = ground.getWrapObjectSet();
BodyRef.cloneAndAppend(TRIlongglen_l);


%% clavicle body
clavicle = Body();
clavicle.setName('clavicle');
clavicle.setMass(1E-5);
clavicle.setMassCenter(Vec3(-0.011096, 0.0063723, 0.054168));

Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
clavicle.setInertia(Inertiavect);

clavicle.addDisplayGeometry('clavicle.vtp');

% create a weldjoint between thorax and clavicle
locationInParentVec3 = ArrayDouble.createVec3([0.006325, 0.00693, 0.025465]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

clavicleToThorax = WeldJoint('clavicleToThorax', ground, locationInParentVec3, zeroVec3, clavicle, locationInChildVec3, zeroVec3, false);

model.addBody(clavicle);


%% scapula body
scapula = Body();
scapula.setName('scapula');
scapula.setMass(1E-5);
scapula.setMassCenter(Vec3(-0.054694, -0.035032, -0.043734));

Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
scapula.setInertia(Inertiavect);

scapula.addDisplayGeometry('scapula.vtp');

% create a weldjoint between thorax and scapula
locationInParentVec3 = ArrayDouble.createVec3([-0.01433, 0.02007, 0.135535]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

scapulaToClavicle = WeldJoint('scapulaToClavicle', clavicle, locationInParentVec3, zeroVec3, scapula, locationInChildVec3, zeroVec3, false);

model.addBody(scapula);

%% humerus body
% create moment of inertia vector for humerus
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,0.01481);
Inertiavect.set(1,0.004551);
Inertiavect.set(2,0.013193);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);

humerus = Body();
humerus.setName('humerus');
humerus.setMass(1.864572);
humerus.setMassCenter(Vec3(0, -0.180496, 0));
humerus.setInertia(Inertiavect);

humerus.addDisplayGeometry('humerus_r.vtp');

% create CustomJoint between thorax and humerus
locationInParentVec3 = ArrayDouble.createVec3([-0.01745, -0.007, 0.17]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

humerusToThorax = CustomJoint('r_shoulder', ground, locationInParentVec3, zeroVec3, humerus, locationInChildVec3, zeroVec3, false);

shoulderCS= humerusToThorax.upd_CoordinateSet();  % create CoordinateSet (DOF)
shoulderCoord= Coordinate();  % create shoulderCoord as a coordinate
shoulderCoord.setName('r_shoulder_elev'); % set name
shoulderCoord.setDefaultValue(0);  % set default position (angle)
shoulderCoord.setDefaultSpeedValue(0);  % set default velocity
shoulderCoord.setRangeMin(-1.57079); % set range [min;max] in radians
shoulderCoord.setRangeMax(3.14159);
shoulderCoord.setDefaultClamped(false); % clamped = limit coordinate value to range
shoulderCoord.setDefaultLocked(false); % locked  = limit coordinate value to default

shoulderCS.cloneAndAppend(shoulderCoord); % add coordinate to Coordinate Set

% set for SpatialTranform axis value and DOF --> SpatialTransform are 3
% rotations and 3 translations
SpatialTransform = humerusToThorax.get_SpatialTransform();
% first set rotations, then traslations
rotation1 = SpatialTransform.get_rotation1(); % get rotation1
rotation1.set_coordinates(0,'r_shoulder_elev');  % set coordinate for rotation1
rotation1.set_axis(Vec3(-0.05889802, 0.0023, 0.99826136)); % set rotation axis (with CustomJoint I can change axis)
linear_function = LinearFunction(); % create linear transform function and set coefficients y=ax+b 
coefficents = ArrayDouble(1, 2); % set coefficient vector dimension
coefficents.set(0,1); % set a=1 (first coefficient)
coefficents.set(1,0); % set b=0 (second coefficient)
linear_function.setCoefficients(coefficents); % add coefficients to function
rotation1.set_function(linear_function);  % add function to rotation1

% I haven't other coordinates so I set Constant function = 0
rotation2 = SpatialTransform.get_rotation2();
rotation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
rotation2.set_function(constant);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_axis(Vec3(0.99826136, 0, 0.05889802));
constant = Constant();
constant.setValue(0);
rotation3.set_function(constant);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

% add wrapping objects 
TRIlonghh = WrapEllipsoid();
TRIlonghh.setName('TRIlonghh');
% set Ellipsoid dimensions
dimension = TRIlonghh.getPropertyByName('dimensions');
x_dimension = PropertyHelper.getValueDouble(dimension , 0);
PropertyHelper.setValueDouble(0.035,dimension, 0);
y_dimension = PropertyHelper.getValueDouble(dimension , 1);
PropertyHelper.setValueDouble(0.02,dimension, 1);
z_dimension = PropertyHelper.getValueDouble(dimension , 2);
PropertyHelper.setValueDouble(0.02,dimension, 2);
TRIlonghh.setQuadrantName('z');
TRIlonghh.connectToModelAndBody(model,humerus);
% set Ellipsoid rotation
xyz_body_rotation = TRIlonghh.getPropertyByName('xyz_body_rotation');
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(3.00162,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);
PropertyHelper.setValueDouble(-0.853466,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2);
PropertyHelper.setValueDouble(2.57419,xyz_body_rotation, 2);
% set translation
prop = TRIlonghh.getPropertyByName('translation');
x_translation = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(-0.0078,prop, 0);
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.0041,prop, 1);
z_translation = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(-0.0014,prop, 2);

BodyRef = humerus.getWrapObjectSet(); % add to model
BodyRef.cloneAndAppend(TRIlonghh);


BIClonghh = WrapEllipsoid();
BIClonghh.setName('BIClonghh');
% set Ellipsoid dimensions
dimension = BIClonghh.getPropertyByName('dimensions');
x_dimension = PropertyHelper.getValueDouble(dimension , 0);
PropertyHelper.setValueDouble(0.025,dimension, 0);
y_dimension = PropertyHelper.getValueDouble(dimension , 1);
PropertyHelper.setValueDouble(0.02,dimension, 1);
z_dimension = PropertyHelper.getValueDouble(dimension , 2);
PropertyHelper.setValueDouble(0.02,dimension, 2);
BIClonghh.setQuadrantName('-y');
BIClonghh.connectToModelAndBody(model,humerus);
% set rotation
xyz_body_rotation = BIClonghh.getPropertyByName('xyz_body_rotation');
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(-2.00434,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);
PropertyHelper.setValueDouble(-1.00164,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2);
PropertyHelper.setValueDouble(0.975465,xyz_body_rotation, 2);
% set translation
prop = BIClonghh.getPropertyByName('translation');
x_translation = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.0033,prop, 0);
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(0.0073,prop, 1);
z_translation = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(0.0003,prop, 2);

BodyRef = humerus.getWrapObjectSet();  % add to body
BodyRef.cloneAndAppend(BIClonghh);


TRI = WrapCylinder();
TRI.setName('TRI');
TRI.setRadius(0.016);
TRI.setLength(0.05);
TRI.setQuadrantName('all');
TRI.connectToModelAndBody(model,humerus);
% set rotation
xyz_body_rotation = TRI.getPropertyByName('xyz_body_rotation');
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(-0.14015,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);
PropertyHelper.setValueDouble(-0.00628319,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2);
PropertyHelper.setValueDouble(0.154985,xyz_body_rotation, 2);
% set translation
prop = TRI.getPropertyByName('translation');
x_translation = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.0028,prop, 0);
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.2919,prop, 1);
z_translation = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(-0.0069,prop, 2);

BodyRef = humerus.getWrapObjectSet();
BodyRef.cloneAndAppend(TRI);

model.addBody(humerus);

%% ulna body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,0.019281);
Inertiavect.set(1,0.001571);
Inertiavect.set(2,0.020062);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, -0.181479, 0);

ulna = Body();
ulna.setName('ulna');
ulna.setMass(1.534315);
ulna.setMassCenter(mass_center);
ulna.setInertia(Inertiavect);

ulna.addDisplayGeometry('ulna_r.vtp');

% create joint between humerus and ulna
locationInParentVec3 = ArrayDouble.createVec3([0.0061, -0.2904, -0.0123]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

ulnaToHumerus = CustomJoint('r_elbow', humerus, locationInParentVec3, zeroVec3, ulna, locationInChildVec3, zeroVec3, false);

% create coordinateSet, add coordinates and set TransformAxis
elbowCS= ulnaToHumerus.upd_CoordinateSet();
elbowCoord= Coordinate();
elbowCoord.setName('r_elbow_flex');
elbowCoord.setDefaultValue(0);
elbowCoord.setDefaultSpeedValue(0);
elbowCoord.setRangeMin(0);
elbowCoord.setRangeMax(2.268928027593);
elbowCoord.setDefaultClamped(false);
elbowCoord.setDefaultLocked(false);

elbowCS.cloneAndAppend(elbowCoord);

SpatialTransform = ulnaToHumerus.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
rotation1.set_function(constant);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
rotation2.set_function(constant);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_coordinates(0,'r_elbow_flex');
rotation3.set_axis(Vec3(0.049400012358, 0.03660009156, 0.998108249695));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation3.set_function(linear_function)

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

model.addBody(ulna);

%% radius body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

radius = Body();
radius.setName('radius');
radius.setMass(1E-5);
radius.setMassCenter(mass_center);
radius.setInertia(Inertiavect);

radius.addDisplayGeometry('radius_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0004, -0.011503, 0.019999]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

radiusToUlna = CustomJoint('r_elbow_radio_ulna', ulna, locationInParentVec3, zeroVec3, radius, locationInChildVec3, zeroVec3, false);

elbowruCS= radiusToUlna.upd_CoordinateSet();
elbowruCoord= Coordinate();
elbowruCoord.setName('r_elbow_prosup');
elbowruCoord.setDefaultValue(-1.570796326795);
elbowruCoord.setDefaultSpeedValue(0);
elbowruCoord.setRangeMin(-1.570796326795);
elbowruCoord.setRangeMax(1.570796326795);
elbowruCoord.setDefaultClamped(true);
elbowruCoord.setDefaultLocked(true);

elbowruCS.cloneAndAppend(elbowruCoord);

SpatialTransform = radiusToUlna.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
rotation1.set_function(constant);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_coordinates(0,'r_elbow_prosup');
rotation2.set_axis(Vec3(-0.017160993842, 0.992665643782, -0.119667957057));
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation2.set_function(linear_function);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
rotation3.set_function(constant);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

model.addBody(radius);

%% lunate body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

lunate = Body();
lunate.setName('lunate');
lunate.setMass(1E-5);
lunate.setMassCenter(mass_center);
lunate.setInertia(Inertiavect);

lunate.addDisplayGeometry('lunate_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.018, -0.242, 0.025]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

lunateToRadius = WeldJoint('lunateToRadius', radius, locationInParentVec3, zeroVec3, lunate, locationInChildVec3, zeroVec3, false);

model.addBody(lunate);

%% scaphoid body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

scaphoid = Body();
scaphoid.setName('scaphoid');
scaphoid.setMass(0.00001);
scaphoid.setMassCenter(mass_center);
scaphoid.setInertia(Inertiavect);

scaphoid.addDisplayGeometry('scaphoid_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.012345, -0.004464, -0.001254]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

scaphoidToLunate = WeldJoint('scaphoidToLunate', lunate, locationInParentVec3, zeroVec3, scaphoid, locationInChildVec3, zeroVec3, false);

model.addBody(scaphoid);

%% pisiform body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

pisiform = Body();
pisiform.setName('pisiform');
pisiform.setMass(0.00001);
pisiform.setMassCenter(mass_center);
pisiform.setInertia(Inertiavect);

pisiform.addDisplayGeometry('pisiform_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.013388, -0.009886, -0.010593]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

pisiformToLunate = WeldJoint('pisiformToLunate', lunate, locationInParentVec3, zeroVec3, pisiform, locationInChildVec3, zeroVec3, false);

model.addBody(pisiform);

%% triquetrum body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

triquetrum = Body();
triquetrum.setName('triquetrum');
triquetrum.setMass(0.00001);
triquetrum.setMassCenter(mass_center);
triquetrum.setInertia(Inertiavect);

triquetrum.addDisplayGeometry('triquetrum_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.010784, -0.007499, -0.001289]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

triquetrumToLunate = WeldJoint('triquetrumToLunate', lunate, locationInParentVec3, zeroVec3, triquetrum, locationInChildVec3, zeroVec3, false);

model.addBody(triquetrum);

%% capitate body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

capitate = Body();
capitate.setName('capitate');
capitate.setMass(0.00001);
capitate.setMassCenter(mass_center);
capitate.setInertia(Inertiavect);

capitate.addDisplayGeometry('capitate_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.003992, -0.015054, 0.002327]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

capitateToLunate = WeldJoint('triquetrumToLunate', lunate, locationInParentVec3, zeroVec3, capitate, locationInChildVec3, zeroVec3, false);

model.addBody(capitate);

%% trapezium body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

trapezium = Body();
trapezium.setName('trapezium');
trapezium.setMass(0.00001);
trapezium.setMassCenter(mass_center);
trapezium.setInertia(Inertiavect);

trapezium.addDisplayGeometry('trapezium_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.015293, -0.004569, -0.010308]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

trapeziumToCapitate = WeldJoint('trapeziumToCapitate', capitate, locationInParentVec3, zeroVec3, trapezium, locationInChildVec3, zeroVec3, false);

model.addBody(trapezium);

%% trapezoid body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

trapezoid = Body();
trapezoid.setName('trapezoid');
trapezoid.setMass(0.00001);
trapezoid.setMassCenter(mass_center);
trapezoid.setInertia(Inertiavect);

trapezoid.addDisplayGeometry('trapezoid_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.009143, -0.004062, -0.002464]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

trapezoidToCapitate = WeldJoint('trapezoidToCapitate', capitate, locationInParentVec3, zeroVec3, trapezoid, locationInChildVec3, zeroVec3, false);

model.addBody(trapezoid);

%% hamate body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

hamate = Body();
hamate.setName('hamate');
hamate.setMass(0.00001);
hamate.setMassCenter(mass_center);
hamate.setInertia(Inertiavect);

hamate.addDisplayGeometry('hamate_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.010969, -0.002495, -0.00075]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

hamateToCapitate = WeldJoint('hamateToCapitate', capitate, locationInParentVec3, zeroVec3, hamate, locationInChildVec3, zeroVec3, false);

model.addBody(hamate);

%% firstmc body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

firstmc = Body();
firstmc.setName('firstmc');
firstmc.setMass(0.00001);
firstmc.setMassCenter(mass_center);
firstmc.setInertia(Inertiavect);

firstmc.addDisplayGeometry('1mc_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0072, -0.0054, -0.0025]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

firstmcToTrapezium = WeldJoint('firstmcToTrapezium', trapezium, locationInParentVec3, zeroVec3, firstmc, locationInChildVec3, zeroVec3, false);

model.addBody(firstmc);

%% secondmc body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

secondmc = Body();
secondmc.setName('secondmc');
secondmc.setMass(0.00001);
secondmc.setMassCenter(mass_center);
secondmc.setInertia(Inertiavect);

secondmc.addDisplayGeometry('2mc_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.014685, -0.03762, 0.005032]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

secondmcToCapitate = WeldJoint('secondmcToCapitate', capitate, locationInParentVec3, zeroVec3, secondmc, locationInChildVec3, zeroVec3, false);

model.addBody(secondmc);

%% thirdmc body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

thirdmc = Body();
thirdmc.setName('thirdmc');
thirdmc.setMass(0.00001);
thirdmc.setMassCenter(mass_center);
thirdmc.setInertia(Inertiavect);

thirdmc.addDisplayGeometry('3mc_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.000477, -0.039239, 0.007377]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

thirdmcToCapitate = WeldJoint('thirdmcToCapitate', capitate, locationInParentVec3, zeroVec3, thirdmc, locationInChildVec3, zeroVec3, false);

model.addBody(thirdmc);

%% fourthmc body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

fourthmc = Body();
fourthmc.setName('fourthmc');
fourthmc.setMass(0.00001);
fourthmc.setMassCenter(mass_center);
fourthmc.setInertia(Inertiavect);

fourthmc.addDisplayGeometry('4mc_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.012046, -0.040519, 0.003513]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

fourthmcToCapitate = WeldJoint('fourthmcToCapitate', capitate, locationInParentVec3, zeroVec3, fourthmc, locationInChildVec3, zeroVec3, false);

model.addBody(fourthmc);

%% fifthmc body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

fifthmc = Body();
fifthmc.setName('fifthmc');
fifthmc.setMass(0.00001);
fifthmc.setMassCenter(mass_center);
fifthmc.setInertia(Inertiavect);

fifthmc.addDisplayGeometry('5mc_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.021896, -0.034683, -0.004218]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

fifthmcToCapitate = WeldJoint('fifthmcToCapitate', capitate, locationInParentVec3, zeroVec3, fifthmc, locationInChildVec3, zeroVec3, false);

model.addBody(fifthmc);

%% proximal_thumb body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proximal_thumb = Body();
proximal_thumb.setName('proximal_thumb');
proximal_thumb.setMass(0.00001);
proximal_thumb.setMassCenter(mass_center);
proximal_thumb.setInertia(Inertiavect);

proximal_thumb.addDisplayGeometry('thumbprox_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0165, -0.0292, -0.0127]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

thumbproxToFirstmc = WeldJoint('thumbproxToFirstmc', firstmc, locationInParentVec3, zeroVec3, proximal_thumb, locationInChildVec3, zeroVec3, false);

model.addBody(proximal_thumb);

%% distal_thumb body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distal_thumb = Body();
distal_thumb.setName('distal_thumb');
distal_thumb.setMass(0.00001);
distal_thumb.setMassCenter(mass_center);
distal_thumb.setInertia(Inertiavect);

distal_thumb.addDisplayGeometry('thumbdist_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.014, -0.0259, -0.0101]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

thumbdistTothumbprox = WeldJoint('thumbdistTothumbprox', proximal_thumb, locationInParentVec3, zeroVec3, distal_thumb, locationInChildVec3, zeroVec3, false);

model.addBody(distal_thumb);

%% proxph2 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph2 = Body();
proxph2.setName('2proxph');
proxph2.setMass(0.00001);
proxph2.setMassCenter(mass_center);
proxph2.setInertia(Inertiavect);

proxph2.addDisplayGeometry('2proxph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.003501, -0.028243, 0.00362]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph2Tosecondmc = WeldJoint('proxph2Tosecondmc', secondmc, locationInParentVec3, zeroVec3, proxph2, locationInChildVec3, zeroVec3, false);

model.addBody(proxph2);

%% midph2 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph2 = Body();
midph2.setName('midph2');
midph2.setMass(0.00001);
midph2.setMassCenter(mass_center);
midph2.setInertia(Inertiavect);

midph2.addDisplayGeometry('2midph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.007517, -0.041273, 0.007326]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph2Toproxph2 = WeldJoint('proxph2Toproxph2', proxph2, locationInParentVec3, zeroVec3, midph2, locationInChildVec3, zeroVec3, false);

model.addBody(midph2);

%% distph2 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph2 = Body();
distph2.setName('distph2');
distph2.setMass(0.00001);
distph2.setMassCenter(mass_center);
distph2.setInertia(Inertiavect);

distph2.addDisplayGeometry('2distph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.003333, -0.024888, 0.00122]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph22Tomidph2 = WeldJoint('distph22Tomidph2', midph2, locationInParentVec3, zeroVec3, distph2, locationInChildVec3, zeroVec3, false);

model.addBody(distph2);

%% proxph3 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph3 = Body();
proxph3.setName('3proxph');
proxph3.setMass(0.00001);
proxph3.setMassCenter(mass_center);
proxph3.setInertia(Inertiavect);

proxph3.addDisplayGeometry('3proxph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.00024, -0.02629, 0.001778]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph3Tothirdmc = WeldJoint('proxph3Tothirdmc', thirdmc, locationInParentVec3, zeroVec3, proxph3, locationInChildVec3, zeroVec3, false);

model.addBody(proxph3);

%% midph3 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph3 = Body();
midph3.setName('midph3');
midph3.setMass(0.00001);
midph3.setMassCenter(mass_center);
midph3.setInertia(Inertiavect);

midph3.addDisplayGeometry('3midph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.00165, -0.044211, 0.00623]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

midph3Toproxph3 = WeldJoint('midph3Toproxph3', proxph3, locationInParentVec3, zeroVec3, midph3, locationInChildVec3, zeroVec3, false);

model.addBody(midph3);

%% distph3 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph3 = Body();
distph3.setName('distph3');
distph3.setMass(0.00001);
distph3.setMassCenter(mass_center);
distph3.setInertia(Inertiavect);

distph3.addDisplayGeometry('3distph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.001365, -0.029047, 0.001954]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph3Tomidph3 = WeldJoint('distph3Tomidph3', midph3, locationInParentVec3, zeroVec3, distph3, locationInChildVec3, zeroVec3, false);

model.addBody(distph3);

%% proxph4 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph4 = Body();
proxph4.setName('4proxph');
proxph4.setMass(0.00001);
proxph4.setMassCenter(mass_center);
proxph4.setInertia(Inertiavect);

proxph4.addDisplayGeometry('4proxph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.00183, -0.023689, -0.000173]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph4Tofourthmc = WeldJoint('proxph4Tofourthmc', fourthmc, locationInParentVec3, zeroVec3, proxph4, locationInChildVec3, zeroVec3, false);

model.addBody(proxph4);

%% midph4 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph4 = Body();
midph4.setName('midph4');
midph4.setMass(0.00001);
midph4.setMassCenter(mass_center);
midph4.setInertia(Inertiavect);

midph4.addDisplayGeometry('4midph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.003528, -0.040255, 0.001345]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

midph4Toproxph4 = WeldJoint('midph4Toproxph4', proxph4, locationInParentVec3, zeroVec3, midph4, locationInChildVec3, zeroVec3, false);

model.addBody(midph4);

%% distph4 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph4 = Body();
distph4.setName('distph4');
distph4.setMass(0.00001);
distph4.setMassCenter(mass_center);
distph4.setInertia(Inertiavect);

distph4.addDisplayGeometry('4distph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.002317, -0.024789, 0.000563]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph4Tomidph4 = WeldJoint('distph4Tomidph4', midph4, locationInParentVec3, zeroVec3, distph4, locationInChildVec3, zeroVec3, false);

model.addBody(distph4);

%% proxph5 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph5 = Body();
proxph5.setName('5proxph');
proxph5.setMass(0.00001);
proxph5.setMassCenter(mass_center);
proxph5.setInertia(Inertiavect);

proxph5.addDisplayGeometry('5proxph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.001597, -0.021421, -0.001496]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph5Tofifthmc = WeldJoint('proxph5Tofifthmc', fifthmc, locationInParentVec3, zeroVec3, proxph5, locationInChildVec3, zeroVec3, false);

model.addBody(proxph5);

%% midph5 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph5 = Body();
midph5.setName('midph5');
midph5.setMass(0.00001);
midph5.setMassCenter(mass_center);
midph5.setInertia(Inertiavect);

midph5.addDisplayGeometry('5midph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.005279, -0.035563, -0.002879]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

midph5Toproxph5 = WeldJoint('midph5Toproxph5', proxph5, locationInParentVec3, zeroVec3, midph5, locationInChildVec3, zeroVec3, false);

model.addBody(midph5);

%% distph5 body
% set very low values of inertia and mass
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph5 = Body();
distph5.setName('distph5');
distph5.setMass(0.00001);
distph5.setMassCenter(mass_center);
distph5.setInertia(Inertiavect);

distph5.addDisplayGeometry('5distph_r.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.002871, -0.020677, -0.002243]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph5Tomidph5 = WeldJoint('distph5Tomidph5', midph5, locationInParentVec3, zeroVec3, distph5, locationInChildVec3, zeroVec3, false);

model.addBody(distph5);

%% clavicle_l body
% for left bodies I used the same procedure as rigth bodies --> see it for comments
% I changed z value from negative to positive and vice versa for
% translations, x and y values for rotations
clavicle_l = Body();
clavicle_l.setName('clavicle_l2');
clavicle_l.setMass(1E-5);
clavicle_l.setMassCenter(Vec3(-0.011096, 0.0063723, -0.054168));

Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
clavicle_l.setInertia(Inertiavect);

clavicle_l.addDisplayGeometry('clavicle_l.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.006325, 0.00693, -0.025465]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

clavicle_lToThorax = WeldJoint('clavicle_lToThorax', ground, locationInParentVec3, zeroVec3, clavicle_l, locationInChildVec3, zeroVec3, false);

model.addBody(clavicle_l);


%% scapula_l body
scapula_l = Body();
scapula_l.setName('scapula_l');
scapula_l.setMass(1E-5);
scapula_l.setMassCenter(Vec3(-0.054694, -0.035032, 0.043734));

Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
scapula_l.setInertia(Inertiavect);

scapula_l.addDisplayGeometry('scapula_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.01433, 0.02007, -0.135535]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

scapula_lToClavicle = WeldJoint('scapula_lToClavicle', clavicle_l, locationInParentVec3, zeroVec3, scapula_l, locationInChildVec3, zeroVec3, false);

model.addBody(scapula_l);

%% humerus_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,0.01481);
Inertiavect.set(1,0.004551);
Inertiavect.set(2,0.013193);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);

humerus_l = Body();
humerus_l.setName('humerus_l');
humerus_l.setMass(1.864572);
humerus_l.setMassCenter(Vec3(0, -0.180496, 0));
humerus_l.setInertia(Inertiavect);

humerus_l.addDisplayGeometry('humerus_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.01745, -0.007, -0.17]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

humerus_lToThorax = CustomJoint('l_shoulder', ground, locationInParentVec3, zeroVec3, humerus_l, locationInChildVec3, zeroVec3, false);

shoulderCS_l= humerus_lToThorax.upd_CoordinateSet();
shoulderCoord_l= Coordinate();
shoulderCoord_l.setName('l_shoulder_elev');
shoulderCoord_l.setDefaultValue(0);
shoulderCoord_l.setDefaultSpeedValue(0);
shoulderCoord_l.setRangeMin(-1.57079);
shoulderCoord_l.setRangeMax(3.14159);
shoulderCoord_l.setDefaultClamped(false);
shoulderCoord_l.setDefaultLocked(false);

shoulderCS_l.cloneAndAppend(shoulderCoord_l);

SpatialTransform = humerus_lToThorax.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_coordinates(0,'l_shoulder_elev');
rotation1.set_axis(Vec3(0.05889802, -0.0023, 0.99826136));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation1.set_function(linear_function);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_axis(Vec3(0, -1, 0));
constant = Constant();
constant.setValue(0);
rotation2.set_function(constant);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_axis(Vec3(-0.99826136, 0, 0.05889802));
constant = Constant();
constant.setValue(0);
rotation3.set_function(constant);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);


TRIlonghh_l = WrapEllipsoid();
TRIlonghh_l.setName('TRIlonghh_l');
dimension = TRIlonghh_l.getPropertyByName('dimensions');
x_dimension = PropertyHelper.getValueDouble(dimension , 0);
PropertyHelper.setValueDouble(0.035,dimension, 0);
y_dimension = PropertyHelper.getValueDouble(dimension , 1);
PropertyHelper.setValueDouble(0.02,dimension, 1);
z_dimension = PropertyHelper.getValueDouble(dimension , 2);
PropertyHelper.setValueDouble(0.02,dimension, 2);

TRIlonghh_l.setQuadrantName('-z');
TRIlonghh_l.connectToModelAndBody(model,humerus_l);

xyz_body_rotation = TRIlonghh_l.getPropertyByName('xyz_body_rotation');
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(-3.00162,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);
PropertyHelper.setValueDouble(0.853466,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2);
PropertyHelper.setValueDouble(2.57419,xyz_body_rotation, 2);

prop = TRIlonghh_l.getPropertyByName('translation');
% get the x translation value
x_translation = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(-0.0078,prop, 0);
% get the y translation value
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.0041,prop, 1);
% get the z translation value
z_translation = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(0.0014,prop, 2);

BodyRef = humerus_l.getWrapObjectSet();
BodyRef.cloneAndAppend(TRIlonghh_l);


BIClonghh_l = WrapEllipsoid();
BIClonghh_l.setName('BIClonghh_l');
dimension = BIClonghh_l.getPropertyByName('dimensions');
x_dimension = PropertyHelper.getValueDouble(dimension , 0);
PropertyHelper.setValueDouble(0.025,dimension, 0);
y_dimension = PropertyHelper.getValueDouble(dimension , 1);
PropertyHelper.setValueDouble(0.02,dimension, 1);
z_dimension = PropertyHelper.getValueDouble(dimension , 2);
PropertyHelper.setValueDouble(0.02,dimension, 2);

BIClonghh_l.setQuadrantName('-y');
BIClonghh_l.connectToModelAndBody(model,humerus_l);

xyz_body_rotation = BIClonghh_l.getPropertyByName('xyz_body_rotation');
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(2.00434,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);
PropertyHelper.setValueDouble(1.00164,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2);
PropertyHelper.setValueDouble(0.975465,xyz_body_rotation, 2);

prop = BIClonghh_l.getPropertyByName('translation');
% get the x translation value
x_translation = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.0033,prop, 0);
% get the y translation value
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(0.0073,prop, 1);
% get the z translation value
z_translation = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(-0.0003,prop, 2);

BodyRef = humerus_l.getWrapObjectSet();
BodyRef.cloneAndAppend(BIClonghh_l);


TRI_l = WrapCylinder();
TRI_l.setName('TRI_l');
TRI_l.setRadius(0.016);
TRI_l.setLength(0.05);
TRI_l.setQuadrantName('all');
TRI_l.connectToModelAndBody(model,humerus_l);

xyz_body_rotation = TRI_l.getPropertyByName('xyz_body_rotation');
x_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 0);
PropertyHelper.setValueDouble(0.14015,xyz_body_rotation, 0);
y_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 1);
PropertyHelper.setValueDouble(0.00628319,xyz_body_rotation, 1);
z_body_rotation = PropertyHelper.getValueDouble(xyz_body_rotation , 2);
PropertyHelper.setValueDouble(0.154985,xyz_body_rotation, 2);

prop = TRI_l.getPropertyByName('translation');
% get the x translation value
x_translation = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.0028,prop, 0);
% get the y translation value
y_translation = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.2919,prop, 1);
% get the z translation value
z_translation = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(0.0069,prop, 2);

BodyRef = humerus_l.getWrapObjectSet();
BodyRef.cloneAndAppend(TRI_l);


model.addBody(humerus_l);


%% ulna_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,0.019281);
Inertiavect.set(1,0.001571);
Inertiavect.set(2,0.020062);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, -0.181479, 0);

ulna_l = Body();
ulna_l.setName('ulna_l');
ulna_l.setMass(1.534315);
ulna_l.setMassCenter(mass_center);
ulna_l.setInertia(Inertiavect);

ulna_l.addDisplayGeometry('ulna_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0061, -0.2904, 0.0123]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

ulna_lToHumerus = CustomJoint('l_elbow', humerus_l, locationInParentVec3, zeroVec3, ulna_l, locationInChildVec3, zeroVec3, false);

elbowCS_l= ulna_lToHumerus.upd_CoordinateSet();
elbowCoord_l= Coordinate();
elbowCoord_l.setName('l_elbow_flex');
elbowCoord_l.setDefaultValue(0);
elbowCoord_l.setDefaultSpeedValue(0);
elbowCoord_l.setRangeMin(0);
elbowCoord_l.setRangeMax(2.268928027593);
elbowCoord_l.setDefaultClamped(false);
elbowCoord_l.setDefaultLocked(false);

elbowCS_l.cloneAndAppend(elbowCoord_l);

SpatialTransform = ulna_lToHumerus.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_axis(Vec3(-1, 0, 0));
constant = Constant();
constant.setValue(0);
rotation1.set_function(constant);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_axis(Vec3(0, -1, 0));
constant = Constant();
constant.setValue(0);
rotation2.set_function(constant);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_coordinates(0,'l_elbow_flex');
rotation3.set_axis(Vec3(-0.049400012358, -0.03660009156, 0.998108249695));
linear_function = LinearFunction();
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation3.set_function(linear_function)

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

model.addBody(ulna_l);

%% radius_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

radius_l = Body();
radius_l.setName('radius_l');
radius_l.setMass(0.00001);
radius_l.setMassCenter(mass_center);
radius_l.setInertia(Inertiavect);

radius_l.addDisplayGeometry('radius_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0004, -0.011503, -0.019999]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

radius_lToUlna = CustomJoint('l_elbow_radio_ulna', ulna_l, locationInParentVec3, zeroVec3, radius_l, locationInChildVec3, zeroVec3, false);

elbowruCS_l= radius_lToUlna.upd_CoordinateSet();
elbowruCoord_l= Coordinate();
elbowruCoord_l.setName('l_elbow_prosup');
elbowruCoord_l.setDefaultValue(-1.570796326795);
elbowruCoord_l.setDefaultSpeedValue(0);
elbowruCoord_l.setRangeMin(-1.570796326795);
elbowruCoord_l.setRangeMax(1.570796326795);
elbowruCoord_l.setDefaultClamped(true);
elbowruCoord_l.setDefaultLocked(true);

elbowruCS_l.cloneAndAppend(elbowruCoord_l);

SpatialTransform = radius_lToUlna.get_SpatialTransform();
rotation1 = SpatialTransform.get_rotation1();
rotation1.set_axis(Vec3(-1, 0, 0));
constant = Constant();
constant.setValue(0);
rotation1.set_function(constant);

rotation2 = SpatialTransform.get_rotation2();
rotation2.set_coordinates(0,'l_elbow_prosup');
rotation2.set_axis(Vec3(0.017160993842, -0.992665643782, -0.119667957057));
coefficents = ArrayDouble(1, 2);
coefficents.set(0,1);
coefficents.set(1,0);
linear_function.setCoefficients(coefficents);
rotation2.set_function(linear_function);

rotation3 = SpatialTransform.get_rotation3();
rotation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
rotation3.set_function(constant);

translation1 = SpatialTransform.get_translation1();
translation1.set_axis(Vec3(1, 0, 0));
constant = Constant();
constant.setValue(0);
translation1.set_function(constant);

translation2 = SpatialTransform.get_translation2();
translation2.set_axis(Vec3(0, 1, 0));
constant = Constant();
constant.setValue(0);
translation2.set_function(constant);

translation3 = SpatialTransform.get_translation3();
translation3.set_axis(Vec3(0, 0, 1));
constant = Constant();
constant.setValue(0);
translation3.set_function(constant);

model.addBody(radius_l);

%% lunate_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

lunate_l = Body();
lunate_l.setName('lunate_l');
lunate_l.setMass(0.00001);
lunate_l.setMassCenter(mass_center);
lunate_l.setInertia(Inertiavect);

lunate_l.addDisplayGeometry('lunate_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.018, -0.242, -0.025]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

lunate_lToRadius = WeldJoint('lunate_lToRadius', radius_l, locationInParentVec3, zeroVec3, lunate_l, locationInChildVec3, zeroVec3, false);

model.addBody(lunate_l);

%% scaphoid_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

scaphoid_l = Body();
scaphoid_l.setName('scaphoid_l');
scaphoid_l.setMass(0.00001);
scaphoid_l.setMassCenter(mass_center);
scaphoid_l.setInertia(Inertiavect);

scaphoid_l.addDisplayGeometry('scaphoid_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.012345, -0.004464, 0.001254]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

scaphoid_lToLunate = WeldJoint('scaphoid_lToLunate', lunate_l, locationInParentVec3, zeroVec3, scaphoid_l, locationInChildVec3, zeroVec3, false);

model.addBody(scaphoid_l);

%% pisiform_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

pisiform_l = Body();
pisiform_l.setName('pisiform_l');
pisiform_l.setMass(0.00001);
pisiform_l.setMassCenter(mass_center);
pisiform_l.setInertia(Inertiavect);

pisiform_l.addDisplayGeometry('pisiform_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.013388, -0.009886, 0.010593]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

pisiform_lToLunate = WeldJoint('pisiform_lToLunate', lunate_l, locationInParentVec3, zeroVec3, pisiform_l, locationInChildVec3, zeroVec3, false);

model.addBody(pisiform_l);

%% triquetrum_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

triquetrum_l = Body();
triquetrum_l.setName('triquetrum_l');
triquetrum_l.setMass(0.00001);
triquetrum_l.setMassCenter(mass_center);
triquetrum_l.setInertia(Inertiavect);

triquetrum_l.addDisplayGeometry('triquetrum_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.010784, -0.007499, 0.001289]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

triquetrum_lToLunate = WeldJoint('triquetrum_lToLunate', lunate_l, locationInParentVec3, zeroVec3, triquetrum_l, locationInChildVec3, zeroVec3, false);

model.addBody(triquetrum_l);

%% capitate_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

capitate_l = Body();
capitate_l.setName('capitate_l');
capitate_l.setMass(0.00001);
capitate_l.setMassCenter(mass_center);
capitate_l.setInertia(Inertiavect);

capitate_l.addDisplayGeometry('capitate_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.003992, -0.015054, -0.002327]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

capitate_lToLunate = WeldJoint('capitate_lToLunate', lunate_l, locationInParentVec3, zeroVec3, capitate_l, locationInChildVec3, zeroVec3, false);

model.addBody(capitate_l);

%% trapezium_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

trapezium_l = Body();
trapezium_l.setName('trapezium_l');
trapezium_l.setMass(0.00001);
trapezium_l.setMassCenter(mass_center);
trapezium_l.setInertia(Inertiavect);

trapezium_l.addDisplayGeometry('trapezium_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.015293, -0.004569, 0.010308]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

trapezium_lToCapitate = WeldJoint('trapezium_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, trapezium_l, locationInChildVec3, zeroVec3, false);

model.addBody(trapezium_l);

%% trapezoid_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

trapezoid_l = Body();
trapezoid_l.setName('trapezoid_l');
trapezoid_l.setMass(0.00001);
trapezoid_l.setMassCenter(mass_center);
trapezoid_l.setInertia(Inertiavect);

trapezoid_l.addDisplayGeometry('trapezoid_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.009143, -0.004062, 0.002464]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

trapezoid_lToCapitate = WeldJoint('trapezoid_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, trapezoid_l, locationInChildVec3, zeroVec3, false);

model.addBody(trapezoid_l);

%% hamate_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

hamate_l = Body();
hamate_l.setName('hamate_l');
hamate_l.setMass(0.00001);
hamate_l.setMassCenter(mass_center);
hamate_l.setInertia(Inertiavect);

hamate_l.addDisplayGeometry('hamate_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.010969, -0.002495, 0.00075]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

hamate_lToCapitate = WeldJoint('hamate_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, hamate_l, locationInChildVec3, zeroVec3, false);

model.addBody(hamate_l);

%% firstmc_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

firstmc_l = Body();
firstmc_l.setName('firstmc_l');
firstmc_l.setMass(0.00001);
firstmc_l.setMassCenter(mass_center);
firstmc_l.setInertia(Inertiavect);

firstmc_l.addDisplayGeometry('1mc_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0072, -0.0054, 0.0025]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

firstmc_lToTrapezium = WeldJoint('firstmc_lToTrapezium', trapezium_l, locationInParentVec3, zeroVec3, firstmc_l, locationInChildVec3, zeroVec3, false);

model.addBody(firstmc_l);

%% secondmc_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

secondmc_l = Body();
secondmc_l.setName('secondmc_l');
secondmc_l.setMass(0.00001);
secondmc_l.setMassCenter(mass_center);
secondmc_l.setInertia(Inertiavect);

secondmc_l.addDisplayGeometry('2mc_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.014685, -0.03762, -0.005032]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

secondmc_lToCapitate = WeldJoint('secondmc_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, secondmc_l, locationInChildVec3, zeroVec3, false);

model.addBody(secondmc_l);

%% thirdmc_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

thirdmc_l = Body();
thirdmc_l.setName('thirdmc_l');
thirdmc_l.setMass(0.00001);
thirdmc_l.setMassCenter(mass_center);
thirdmc_l.setInertia(Inertiavect);

thirdmc_l.addDisplayGeometry('3mc_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.000477, -0.039239, -0.007377]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

thirdmc_lToCapitate = WeldJoint('thirdmc_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, thirdmc_l, locationInChildVec3, zeroVec3, false);

model.addBody(thirdmc_l);

%% fourthmc_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

fourthmc_l = Body();
fourthmc_l.setName('fourthmc_l');
fourthmc_l.setMass(0.00001);
fourthmc_l.setMassCenter(mass_center);
fourthmc_l.setInertia(Inertiavect);

fourthmc_l.addDisplayGeometry('4mc_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.012046, -0.040519, -0.003513]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

fourthmc_lToCapitate = WeldJoint('fourthmc_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, fourthmc_l, locationInChildVec3, zeroVec3, false);

model.addBody(fourthmc_l);

%% fifthmc_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

fifthmc_l = Body();
fifthmc_l.setName('fifthmc_l');
fifthmc_l.setMass(0.00001);
fifthmc_l.setMassCenter(mass_center);
fifthmc_l.setInertia(Inertiavect);

fifthmc_l.addDisplayGeometry('5mc_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.021896, -0.034683, 0.004218]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

fifthmc_lToCapitate = WeldJoint('fifthmc_lToCapitate', capitate_l, locationInParentVec3, zeroVec3, fifthmc_l, locationInChildVec3, zeroVec3, false);

model.addBody(fifthmc_l);

%% proximal_thumb_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proximal_thumb_l = Body();
proximal_thumb_l.setName('proximal_thumb_l');
proximal_thumb_l.setMass(0.00001);
proximal_thumb_l.setMassCenter(mass_center);
proximal_thumb_l.setInertia(Inertiavect);

proximal_thumb_l.addDisplayGeometry('thumbprox_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.0165, -0.0292, 0.0127]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

thumbprox_lToFirstmc = WeldJoint('thumbprox_lToFirstmc', firstmc_l, locationInParentVec3, zeroVec3, proximal_thumb_l, locationInChildVec3, zeroVec3, false);

model.addBody(proximal_thumb_l);

%% distal_thumb_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distal_thumb_l = Body();
distal_thumb_l.setName('distal_thumb_l');
distal_thumb_l.setMass(0.00001);
distal_thumb_l.setMassCenter(mass_center);
distal_thumb_l.setInertia(Inertiavect);

distal_thumb_l.addDisplayGeometry('thumbdist_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.014, -0.0259, 0.0101]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

thumbdist_lTothumbprox = WeldJoint('thumbdist_lTothumbprox', proximal_thumb_l, locationInParentVec3, zeroVec3, distal_thumb_l, locationInChildVec3, zeroVec3, false);

model.addBody(distal_thumb_l);

%% proxph2_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph2_l = Body();
proxph2_l.setName('proxph2_l');
proxph2_l.setMass(0.00001);
proxph2_l.setMassCenter(mass_center);
proxph2_l.setInertia(Inertiavect);

proxph2_l.addDisplayGeometry('2proxph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.003501, -0.028243, -0.00362]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph2_lTosecondmc = WeldJoint('proxph2_lTosecondmc', secondmc_l, locationInParentVec3, zeroVec3, proxph2_l, locationInChildVec3, zeroVec3, false);

model.addBody(proxph2_l);

%% midph2_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph2_l = Body();
midph2_l.setName('midph2_l');
midph2_l.setMass(0.00001);
midph2_l.setMassCenter(mass_center);
midph2_l.setInertia(Inertiavect);

midph2_l.addDisplayGeometry('2midph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.007517, -0.041273, -0.007326]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph2_lToproxph2 = WeldJoint('proxph2_lToproxph2', proxph2_l, locationInParentVec3, zeroVec3, midph2_l, locationInChildVec3, zeroVec3, false);

model.addBody(midph2_l);

%% distph2_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph2_l = Body();
distph2_l.setName('distph2_l');
distph2_l.setMass(0.00001);
distph2_l.setMassCenter(mass_center);
distph2_l.setInertia(Inertiavect);

distph2_l.addDisplayGeometry('2distph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.003333, -0.024888, -0.00122]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph2_lTomidph2 = WeldJoint('distph2_lTomidph2', midph2_l, locationInParentVec3, zeroVec3, distph2_l, locationInChildVec3, zeroVec3, false);

model.addBody(distph2_l);

%% proxph3_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph3_l = Body();
proxph3_l.setName('proxph3_l');
proxph3_l.setMass(0.00001);
proxph3_l.setMassCenter(mass_center);
proxph3_l.setInertia(Inertiavect);

proxph3_l.addDisplayGeometry('3proxph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.00024, -0.02629, -0.001778]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph3_lTothirdmc = WeldJoint('proxph3_lTothirdmc', thirdmc_l, locationInParentVec3, zeroVec3, proxph3_l, locationInChildVec3, zeroVec3, false);

model.addBody(proxph3_l);

%% midph3_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph3_l = Body();
midph3_l.setName('midph3_l');
midph3_l.setMass(0.00001);
midph3_l.setMassCenter(mass_center);
midph3_l.setInertia(Inertiavect);

midph3_l.addDisplayGeometry('3midph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.00165, -0.044211, -0.00623]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

midph3_lToproxph3 = WeldJoint('midph3_lToproxph3', proxph3_l, locationInParentVec3, zeroVec3, midph3_l, locationInChildVec3, zeroVec3, false);

model.addBody(midph3_l);

%% distph3_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph3_l = Body();
distph3_l.setName('distph3_l');
distph3_l.setMass(0.00001);
distph3_l.setMassCenter(mass_center);
distph3_l.setInertia(Inertiavect);

distph3_l.addDisplayGeometry('3distph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([0.001365, -0.029047, -0.001954]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph3_lTomidph3 = WeldJoint('distph3_lTomidph3', midph3_l, locationInParentVec3, zeroVec3, distph3_l, locationInChildVec3, zeroVec3, false);

model.addBody(distph3_l);

%% proxph4_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph4_l = Body();
proxph4_l.setName('proxph4_l');
proxph4_l.setMass(0.00001);
proxph4_l.setMassCenter(mass_center);
proxph4_l.setInertia(Inertiavect);

proxph4_l.addDisplayGeometry('4proxph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.00183, -0.023689, 0.000173]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph4_lTofourthmc = WeldJoint('proxph4_lTofourthmc', fourthmc_l, locationInParentVec3, zeroVec3, proxph4_l, locationInChildVec3, zeroVec3, false);

model.addBody(proxph4_l);

%% midph4_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph4_l = Body();
midph4_l.setName('midph4_l');
midph4_l.setMass(0.00001);
midph4_l.setMassCenter(mass_center);
midph4_l.setInertia(Inertiavect);

midph4_l.addDisplayGeometry('4midph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.003528, -0.040255, -0.001345]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

midph4_lToproxph4 = WeldJoint('midph4_lToproxph4', proxph4_l, locationInParentVec3, zeroVec3, midph4_l, locationInChildVec3, zeroVec3, false);

model.addBody(midph4_l);

%% distph4_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph4_l = Body();
distph4_l.setName('distph4_l');
distph4_l.setMass(0.00001);
distph4_l.setMassCenter(mass_center);
distph4_l.setInertia(Inertiavect);

distph4_l.addDisplayGeometry('4distph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.002317, -0.024789, -0.000563]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph4_lTomidph4 = WeldJoint('distph4_lTomidph4', midph4_l, locationInParentVec3, zeroVec3, distph4_l, locationInChildVec3, zeroVec3, false);

model.addBody(distph4_l);

%% proxph5_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

proxph5_l = Body();
proxph5_l.setName('proxph5_l');
proxph5_l.setMass(0.00001);
proxph5_l.setMassCenter(mass_center);
proxph5_l.setInertia(Inertiavect);

proxph5_l.addDisplayGeometry('5proxph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.001597, -0.021421, 0.001496]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

proxph5_lTofifthmc = WeldJoint('proxph5_lTofifthmc', fifthmc_l, locationInParentVec3, zeroVec3, proxph5_l, locationInChildVec3, zeroVec3, false);

model.addBody(proxph5_l);

%% midph5_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

midph5_l = Body();
midph5_l.setName('midph5_l');
midph5_l.setMass(0.00001);
midph5_l.setMassCenter(mass_center);
midph5_l.setInertia(Inertiavect);

midph5_l.addDisplayGeometry('5midph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.005279, -0.035563, 0.002879]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

midph5_lToproxph5 = WeldJoint('midph5_lToproxph5', proxph5_l, locationInParentVec3, zeroVec3, midph5_l, locationInChildVec3, zeroVec3, false);

model.addBody(midph5_l);

%% distph5_l body
Inertiavect = ArrayDouble(1, 6);
Inertiavect.set(0,1E-5);
Inertiavect.set(1,1E-5);
Inertiavect.set(2,1E-5);
Inertiavect.set(3,0);
Inertiavect.set(4,0);
Inertiavect.set(5,0);
mass_center=Vec3(0, 0, 0);

distph5_l = Body();
distph5_l.setName('distph5_l');
distph5_l.setMass(0.00001);
distph5_l.setMassCenter(mass_center);
distph5_l.setInertia(Inertiavect);

distph5_l.addDisplayGeometry('5distph_l2.vtp');

locationInParentVec3 = ArrayDouble.createVec3([-0.002871, -0.020677, 0.002243]);
locationInChildVec3 = ArrayDouble.createVec3([0, 0, 0]);

distph5_lTomidph5 = WeldJoint('distph5_lTomidph5', midph5_l, locationInParentVec3, zeroVec3, distph5_l, locationInChildVec3, zeroVec3, false);

model.addBody(distph5_l);

%% rigth arm muscles
% Set muscle parameters TRIlong
maxIsometricForce  = 798.52;
optimalFiberLength = 0.134;
tendonSlackLength  = 0.143;
pennationAngle 	   = 0.20943951;

% Create new muscle
TRIlong = Thelen2003Muscle(); 
TRIlong.setName('TRIlong')
TRIlong.setMaxIsometricForce(maxIsometricForce)
TRIlong.setOptimalFiberLength(optimalFiberLength)
TRIlong.setTendonSlackLength(tendonSlackLength);
TRIlong.setPennationAngleAtOptimalFiberLength(pennationAngle)
TRIlong.setMaxContractionVelocity(10);
TRIlong.setActivationTimeConstant(0.01);
TRIlong.setDeactivationTimeConstant(0.04);
TRIlong.setFmaxTendonStrain(0.033);
TRIlong.setFmaxFiberStrain(0.6);
TRIlong.setKshapeActive(0.5);
TRIlong.setKshapePassive(4);
TRIlong.setAf(0.3);
TRIlong.setFlen(1.8);

% create path for muscle with fixed point
TRIlong.addNewPathPoint('TRIlong-P1', ground, ArrayDouble.createVec3([-0.05365, -0.01373, 0.14723])); 
TRIlong.addNewPathPoint('TRIlong-P2', humerus, ArrayDouble.createVec3([-0.02714, -0.1141, -0.00664]));
TRIlong.addNewPathPoint('TRIlong-P3', humerus, ArrayDouble.createVec3([-0.03184, -0.22637, -0.01217]));
TRIlong.addNewPathPoint('TRIlong-P4', humerus, ArrayDouble.createVec3([-0.01743, -0.26757, -0.01208]));
TRIlong.addNewPathPoint('TRIlong-P5', ulna, ArrayDouble.createVec3([-0.0219, 0.01046, -0.00078]));

%Create the Muscle Wrap Object
TRI_muscle=PathWrap();
TRI_muscle.setName('TRI');
TRI_muscle.setWrapObject(TRI);
geoPath=TRIlong.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet.cloneAndAppend(TRI_muscle);   %Add the wrap created above to the muscles wrap set

TRIlonghh_muscle=PathWrap();
TRIlonghh_muscle.setName('TRIlonghh');
TRIlonghh_muscle.setWrapObject(TRIlonghh);
geoPath=TRIlong.getGeometryPath();  %Get the muscles geometry
TRIlonghh_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
TRIlonghh_wrapSet.cloneAndAppend(TRIlonghh_muscle)

TRIlongglen_muscle=PathWrap();
TRIlongglen_muscle.setName('TRIlongglen');
TRIlongglen_muscle.setWrapObject(TRIlongglen);
geoPath=TRIlong.getGeometryPath();  %Get the muscles geometry
TRIlongglen_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
TRIlongglen_wrapSet.cloneAndAppend(TRIlongglen_muscle)

model.addForce(TRIlong)


% Set muscle parameters TRIlat
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.098;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRIlat = Thelen2003Muscle();
TRIlat.setName('TRIlat')
TRIlat.setMaxIsometricForce(maxIsometricForce)
TRIlat.setOptimalFiberLength(optimalFiberLength)
TRIlat.setTendonSlackLength(tendonSlackLength);
TRIlat.setPennationAngleAtOptimalFiberLength(pennationAngle)
TRIlat.setMaxContractionVelocity(10);
TRIlat.setActivationTimeConstant(0.01);
TRIlat.setDeactivationTimeConstant(0.04);
TRIlat.setFmaxTendonStrain(0.033);
TRIlat.setFmaxFiberStrain(0.6);
TRIlat.setKshapeActive(0.5);
TRIlat.setKshapePassive(4);
TRIlat.setAf(0.3);
TRIlat.setFlen(1.8);

% Path for TRIlat
TRIlat.addNewPathPoint('TRIlat-P1', humerus, ArrayDouble.createVec3([-0.00599, -0.12646, 0.00428]));
TRIlat.addNewPathPoint('TRIlat-P2', humerus, ArrayDouble.createVec3([-0.02344, -0.14528, 0.00928]));
TRIlat.addNewPathPoint('TRIlat-P3', humerus, ArrayDouble.createVec3([-0.03184, -0.22637, -0.01217]));
TRIlat.addNewPathPoint('TRIlat-P4', humerus, ArrayDouble.createVec3([-0.01743, -0.26757, -0.01208]));
TRIlat.addNewPathPoint('TRIlat-P5', ulna, ArrayDouble.createVec3([-0.0219, 0.01046, -0.00078]));

%Create the Muscle Wrap Object
TRI_muscle=PathWrap();
TRI_muscle.setName('TRI');
TRI_muscle.setWrapObject(TRI);
geoPath=TRIlat.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet.cloneAndAppend(TRI_muscle);   %Add the wrap created above to the muscles wrap set

model.addForce(TRIlat)


% Set muscle parameters TRImed
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.0908;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRImed = Thelen2003Muscle();
TRImed.setName('TRImed')
TRImed.setMaxIsometricForce(maxIsometricForce)
TRImed.setOptimalFiberLength(optimalFiberLength)
TRImed.setTendonSlackLength(tendonSlackLength);
TRImed.setPennationAngleAtOptimalFiberLength(pennationAngle)
TRImed.setMaxContractionVelocity(10);
TRImed.setActivationTimeConstant(0.01);
TRImed.setDeactivationTimeConstant(0.04);
TRImed.setFmaxTendonStrain(0.033);
TRImed.setFmaxFiberStrain(0.6);
TRImed.setKshapeActive(0.5);
TRImed.setKshapePassive(4);
TRImed.setAf(0.3);
TRImed.setFlen(1.8);

% Path for TRImed
TRImed.addNewPathPoint('TRImed-P1', humerus, ArrayDouble.createVec3([-0.00838, -0.13695, -0.00906]));
TRImed.addNewPathPoint('TRImed-P2', humerus, ArrayDouble.createVec3([-0.02601, -0.15139, -0.0108]));
TRImed.addNewPathPoint('TRImed-P3', humerus, ArrayDouble.createVec3([-0.03184, -0.22637, -0.01217]));
TRImed.addNewPathPoint('TRImed-P4', humerus, ArrayDouble.createVec3([-0.01743, -0.26757, -0.01208]));
TRImed.addNewPathPoint('TRImed-P5', ulna, ArrayDouble.createVec3([-0.0219, 0.01046, -0.00078]));

%Create the Muscle Wrap Object
TRI_muscle=PathWrap();
TRI_muscle.setName('TRI');
TRI_muscle.setWrapObject(TRI);
geoPath=TRImed.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet.cloneAndAppend(TRI_muscle);   %Add the wrap created above to the muscles wrap set

model.addForce(TRImed)


% Set muscle parameters BIClong
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1157;
tendonSlackLength  = 0.2723;
pennationAngle 	   = 0;

% Create new muscle
BIClong = Thelen2003Muscle();
BIClong.setName('BIClong')
BIClong.setMaxIsometricForce(maxIsometricForce)
BIClong.setOptimalFiberLength(optimalFiberLength)
BIClong.setTendonSlackLength(tendonSlackLength);
BIClong.setPennationAngleAtOptimalFiberLength(pennationAngle)
BIClong.setMaxContractionVelocity(10);
BIClong.setActivationTimeConstant(0.01);
BIClong.setDeactivationTimeConstant(0.04);
BIClong.setFmaxTendonStrain(0.033);
BIClong.setFmaxFiberStrain(0.6);
BIClong.setKshapeActive(0.5);
BIClong.setKshapePassive(4);
BIClong.setAf(0.3);
BIClong.setFlen(1.8);

% Path for BIClong
BIClong.addNewPathPoint('BIClong-P1', ground, ArrayDouble.createVec3([-0.039235, 0.00347, 0.14795]));
BIClong.addNewPathPoint('BIClong-P2', ground, ArrayDouble.createVec3([-0.028945, 0.01391, 0.15639]));
BIClong.addNewPathPoint('BIClong-P3', humerus, ArrayDouble.createVec3([0.02131, 0.01793, 0.01028]));
BIClong.addNewPathPoint('BIClong-P4', humerus, ArrayDouble.createVec3([0.02378, -0.00511, 0.01201]));
BIClong.addNewPathPoint('BIClong-P5', humerus, ArrayDouble.createVec3([0.01345, -0.02827, 0.00136]));
BIClong.addNewPathPoint('BIClong-P6', humerus, ArrayDouble.createVec3([0.01068, -0.07736, -0.00165]));
BIClong.addNewPathPoint('BIClong-P7', humerus, ArrayDouble.createVec3([0.01703, -0.12125, 0.00024]));
BIClong.addNewPathPoint('BIClong-P8', humerus, ArrayDouble.createVec3([0.0228, -0.1754, -0.0063]));
BIClong.addNewPathPoint('BIClong-P9', ulna, ArrayDouble.createVec3([0.00751, -0.04839, 0.02179]));

%Create the Muscle Wrap Object
BIClonghh_muscle=PathWrap();
BIClonghh_muscle.setName('BIClonghh');
BIClonghh_muscle.setWrapObject(BIClonghh);

geoPath=BIClong.getGeometryPath();  %Get the muscles geometry
BIClonghh_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
BIClonghh_wrapSet.cloneAndAppend(BIClonghh_muscle);   %Add the wrap created above to the muscles wrap set

model.addForce(BIClong)


% Set muscle parameters BICshort
maxIsometricForce  = 435.56;
optimalFiberLength = 0.1321;
tendonSlackLength  = 0.1923;
pennationAngle 	   = 0;

% Create new muscle
BICshort = Thelen2003Muscle();
BICshort.setName('BICshort')
BICshort.setMaxIsometricForce(maxIsometricForce)
BICshort.setOptimalFiberLength(optimalFiberLength)
BICshort.setTendonSlackLength(tendonSlackLength);
BICshort.setPennationAngleAtOptimalFiberLength(pennationAngle)
BICshort.setMaxContractionVelocity(10);
BICshort.setActivationTimeConstant(0.01);
BICshort.setDeactivationTimeConstant(0.04);
BICshort.setFmaxTendonStrain(0.033);
BICshort.setFmaxFiberStrain(0.6);
BICshort.setKshapeActive(0.5);
BICshort.setKshapePassive(4);
BICshort.setAf(0.3);
BICshort.setFlen(1.8);

% Path for BICshort
BICshort.addNewPathPoint('BICshort-P1', ground, ArrayDouble.createVec3([ 0.004675, -0.01231, 0.13475]));
BICshort.addNewPathPoint('BICshort-P2', ground, ArrayDouble.createVec3([-0.007075, -0.04004, 0.14507]));
BICshort.addNewPathPoint('BICshort-P3', humerus, ArrayDouble.createVec3([0.01117, -0.07576, -0.01101]));
BICshort.addNewPathPoint('BICshort-P4', humerus, ArrayDouble.createVec3([0.01703, -0.12125, -0.01079]));
BICshort.addNewPathPoint('BICshort-P5', humerus, ArrayDouble.createVec3([0.0228, -0.1754, -0.0063]));
BICshort.addNewPathPoint('BICshort-P6', ulna, ArrayDouble.createVec3([0.00751, -0.04839, 0.02179]));


model.addForce(BICshort)


% Set muscle parameters BRA
maxIsometricForce  = 987.26;
optimalFiberLength = 0.0858;
tendonSlackLength  = 0.0535;
pennationAngle 	   = 0;

% Create new muscle
BRA = Thelen2003Muscle();
BRA.setName('BRA')
BRA.setMaxIsometricForce(maxIsometricForce)
BRA.setOptimalFiberLength(optimalFiberLength)
BRA.setTendonSlackLength(tendonSlackLength);
BRA.setPennationAngleAtOptimalFiberLength(pennationAngle)
BRA.setMaxContractionVelocity(10);
BRA.setActivationTimeConstant(0.01);
BRA.setDeactivationTimeConstant(0.04);
BRA.setFmaxTendonStrain(0.033);
BRA.setFmaxFiberStrain(0.6);
BRA.setKshapeActive(0.5);
BRA.setKshapePassive(4);
BRA.setAf(0.3);
BRA.setFlen(1.8);

% Path for BRA
BRA.addNewPathPoint('BRA-P1', humerus, ArrayDouble.createVec3([0.0068, -0.1739, -0.0036]));
BRA.addNewPathPoint('BRA-P2', ulna, ArrayDouble.createVec3([-0.0032, -0.0239, 0.0009]));

%Create the Muscle Wrap Object
TRI_muscle=PathWrap();
TRI_muscle.setName('TRI');
TRI_muscle.setWrapObject(TRI);
geoPath=BRA.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet.cloneAndAppend(TRI_muscle);   %Add the wrap created above to the muscles wrap set

model.addForce(BRA)

%% left arm muscles
% Set muscle parameters TRIlong_l
% for comments see TRIlong
% I changed z sign from rigth muscles
maxIsometricForce  = 798.52;
optimalFiberLength = 0.134;
tendonSlackLength  = 0.143;
pennationAngle 	   = 0.20943951;

% Create new muscle
TRIlong_l = Thelen2003Muscle();
TRIlong_l.setName('TRIlong_l')
TRIlong_l.setMaxIsometricForce(maxIsometricForce)
TRIlong_l.setOptimalFiberLength(optimalFiberLength)
TRIlong_l.setTendonSlackLength(tendonSlackLength);
TRIlong_l.setPennationAngleAtOptimalFiberLength(pennationAngle)
TRIlong_l.setMaxContractionVelocity(10);
TRIlong_l.setActivationTimeConstant(0.01);
TRIlong_l.setDeactivationTimeConstant(0.04);
TRIlong_l.setFmaxTendonStrain(0.033);
TRIlong_l.setFmaxFiberStrain(0.6);
TRIlong_l.setKshapeActive(0.5);
TRIlong_l.setKshapePassive(4);
TRIlong_l.setAf(0.3);
TRIlong_l.setFlen(1.8);

% Path for TRIlong_l
TRIlong_l.addNewPathPoint('TRIlong_l-P1', ground, ArrayDouble.createVec3([-0.05365, -0.01373, -0.14723])); 
TRIlong_l.addNewPathPoint('TRIlong_l-P2', humerus_l, ArrayDouble.createVec3([-0.02714, -0.1141, 0.00664]));
TRIlong_l.addNewPathPoint('TRIlong_l-P3', humerus_l, ArrayDouble.createVec3([-0.03184, -0.22637, 0.01217]));
TRIlong_l.addNewPathPoint('TRIlong_l-P4', humerus_l, ArrayDouble.createVec3([-0.01743, -0.26757, 0.01208]));
TRIlong_l.addNewPathPoint('TRIlong_l-P5', ulna_l, ArrayDouble.createVec3([-0.0219, 0.01046, 0.00078]));

%Create the Muscle Wrap Object
TRI_muscle_l=PathWrap();
TRI_muscle_l.setName('TRI_l');
TRI_muscle_l.setWrapObject(TRI_l);
geoPath=TRIlong_l.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet_l.cloneAndAppend(TRI_muscle_l);   %Add the wrap created above to the muscles wrap set

TRIlonghh_muscle_l=PathWrap();
TRIlonghh_muscle_l.setName('TRIlonghh_l');
TRIlonghh_muscle_l.setWrapObject(TRIlonghh_l);
geoPath=TRIlong_l.getGeometryPath();  %Get the muscles geometry
TRIlonghh_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
TRIlonghh_wrapSet_l.cloneAndAppend(TRIlonghh_muscle_l)

TRIlongglen_muscle_l=PathWrap();
TRIlongglen_muscle_l.setName('TRIlongglen_l');
TRIlongglen_muscle_l.setWrapObject(TRIlongglen_l);
geoPath=TRIlong_l.getGeometryPath();  %Get the muscles geometry
TRIlongglen_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
TRIlongglen_wrapSet_l.cloneAndAppend(TRIlongglen_muscle_l)

model.addForce(TRIlong_l)


% Set muscle parameters TRIlat_l
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.098;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRIlat_l = Thelen2003Muscle();
TRIlat_l.setName('TRIlat_l')
TRIlat_l.setMaxIsometricForce(maxIsometricForce)
TRIlat_l.setOptimalFiberLength(optimalFiberLength)
TRIlat_l.setTendonSlackLength(tendonSlackLength);
TRIlat_l.setPennationAngleAtOptimalFiberLength(pennationAngle)
TRIlat_l.setMaxContractionVelocity(10);
TRIlat_l.setActivationTimeConstant(0.01);
TRIlat_l.setDeactivationTimeConstant(0.04);
TRIlat_l.setFmaxTendonStrain(0.033);
TRIlat_l.setFmaxFiberStrain(0.6);
TRIlat_l.setKshapeActive(0.5);
TRIlat_l.setKshapePassive(4);
TRIlat_l.setAf(0.3);
TRIlat_l.setFlen(1.8)

% Path for TRIlat
TRIlat_l.addNewPathPoint('TRIlat_l-P1', humerus_l, ArrayDouble.createVec3([-0.00599, -0.12646, -0.00428]));
TRIlat_l.addNewPathPoint('TRIlat_l-P2', humerus_l, ArrayDouble.createVec3([-0.02344, -0.14528, -0.00928]));
TRIlat_l.addNewPathPoint('TRIlat_l-P3', humerus_l, ArrayDouble.createVec3([-0.03184, -0.22637, 0.01217]));
TRIlat_l.addNewPathPoint('TRIlat_l-P4', humerus_l, ArrayDouble.createVec3([-0.01743, -0.26757, 0.01208]));
TRIlat_l.addNewPathPoint('TRIlat_l-P5', ulna_l, ArrayDouble.createVec3([-0.0219, 0.01046, 0.00078]));

%Create the Muscle Wrap Object
TRI_muscle_l=PathWrap();
TRI_muscle_l.setName('TRI_l');
TRI_muscle_l.setWrapObject(TRI_l);
geoPath=TRIlat_l.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet_l.cloneAndAppend(TRI_muscle_l);   %Add the wrap created above to the muscles wrap set

model.addForce(TRIlat_l)


% Set muscle parameters TRImed_l
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1138;
tendonSlackLength  = 0.0908;
pennationAngle 	   = 0.15707963;

% Create new muscle
TRImed_l = Thelen2003Muscle();
TRImed_l.setName('TRImed_l')
TRImed_l.setMaxIsometricForce(maxIsometricForce)
TRImed_l.setOptimalFiberLength(optimalFiberLength)
TRImed_l.setTendonSlackLength(tendonSlackLength);
TRImed_l.setPennationAngleAtOptimalFiberLength(pennationAngle)
TRImed_l.setMaxContractionVelocity(10);
TRImed_l.setActivationTimeConstant(0.01);
TRImed_l.setDeactivationTimeConstant(0.04);
TRImed_l.setFmaxTendonStrain(0.033);
TRImed_l.setFmaxFiberStrain(0.6);
TRImed_l.setKshapeActive(0.5);
TRImed_l.setKshapePassive(4);
TRImed_l.setAf(0.3);
TRImed_l.setFlen(1.8);


% Path for TRImed
TRImed_l.addNewPathPoint('TRImed_l-P1', humerus_l, ArrayDouble.createVec3([-0.00838, -0.13695, 0.00906]));
TRImed_l.addNewPathPoint('TRImed_l-P2', humerus_l, ArrayDouble.createVec3([-0.02601, -0.15139, 0.0108]));
TRImed_l.addNewPathPoint('TRImed_l-P3', humerus_l, ArrayDouble.createVec3([-0.03184, -0.22637, 0.01217]));
TRImed_l.addNewPathPoint('TRImed_l-P4', humerus_l, ArrayDouble.createVec3([-0.01743, -0.26757, 0.01208]));
TRImed_l.addNewPathPoint('TRImed_l-P5', ulna_l, ArrayDouble.createVec3([-0.0219, 0.01046, 0.00078]));

%Create the Muscle Wrap Object
TRI_muscle_l=PathWrap();
TRI_muscle_l.setName('TRI_l');
TRI_muscle_l.setWrapObject(TRI_l);
geoPath=TRImed_l.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet_l.cloneAndAppend(TRI_muscle_l);   %Add the wrap created above to the muscles wrap set

model.addForce(TRImed_l)


% Set muscle parameters BIClong_l
maxIsometricForce  = 624.3;
optimalFiberLength = 0.1157;
tendonSlackLength  = 0.2723;
pennationAngle 	   = 0;

% Create new muscle
BIClong_l = Thelen2003Muscle();
BIClong_l.setName('BIClong_l')
BIClong_l.setMaxIsometricForce(maxIsometricForce)
BIClong_l.setOptimalFiberLength(optimalFiberLength)
BIClong_l.setTendonSlackLength(tendonSlackLength);
BIClong_l.setPennationAngleAtOptimalFiberLength(pennationAngle)
BIClong_l.setMaxContractionVelocity(10);
BIClong_l.setActivationTimeConstant(0.01);
BIClong_l.setDeactivationTimeConstant(0.04);
BIClong_l.setFmaxTendonStrain(0.033);
BIClong_l.setFmaxFiberStrain(0.6);
BIClong_l.setKshapeActive(0.5);
BIClong_l.setKshapePassive(4);
BIClong_l.setAf(0.3);
BIClong_l.setFlen(1.8);

% Path for BIClong
BIClong_l.addNewPathPoint('BIClong_l-P1', ground, ArrayDouble.createVec3([-0.039235, 0.00347, -0.14795]));
BIClong_l.addNewPathPoint('BIClong_l-P2', ground, ArrayDouble.createVec3([-0.028945, 0.01391, -0.15639]));
BIClong_l.addNewPathPoint('BIClong_l-P3', humerus_l, ArrayDouble.createVec3([0.02131, 0.01793, -0.01028]));
BIClong_l.addNewPathPoint('BIClong_l-P4', humerus_l, ArrayDouble.createVec3([0.02378, -0.00511, -0.01201]));
BIClong_l.addNewPathPoint('BIClong_l-P5', humerus_l, ArrayDouble.createVec3([0.01345, -0.02827, -0.00136]));
BIClong_l.addNewPathPoint('BIClong_l-P6', humerus_l, ArrayDouble.createVec3([0.01068, -0.07736, 0.00165]));
BIClong_l.addNewPathPoint('BIClong_l-P7', humerus_l, ArrayDouble.createVec3([0.01703, -0.12125, -0.00024]));
BIClong_l.addNewPathPoint('BIClong_l-P8', humerus_l, ArrayDouble.createVec3([0.0228, -0.1754, 0.0063]));
BIClong_l.addNewPathPoint('BIClong_l-P9', ulna_l, ArrayDouble.createVec3([0.00751, -0.04839, -0.02179]));

%Create the Muscle Wrap Object
BIClonghh_muscle_l=PathWrap();
BIClonghh_muscle_l.setName('BIClonghh_l');
BIClonghh_muscle_l.setWrapObject(BIClonghh_l);

geoPath=BIClong_l.getGeometryPath();  %Get the muscles geometry
BIClonghh_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
BIClonghh_wrapSet_l.cloneAndAppend(BIClonghh_muscle_l);   %Add the wrap created above to the muscles wrap set

model.addForce(BIClong_l)


% Set muscle parameters BICshort_l
maxIsometricForce  = 435.56;
optimalFiberLength = 0.1321;
tendonSlackLength  = 0.1923;
pennationAngle 	   = 0;

% Create new muscle
BICshort_l = Thelen2003Muscle();
BICshort_l.setName('BICshort_l')
BICshort_l.setMaxIsometricForce(maxIsometricForce)
BICshort_l.setOptimalFiberLength(optimalFiberLength)
BICshort_l.setTendonSlackLength(tendonSlackLength);
BICshort_l.setPennationAngleAtOptimalFiberLength(pennationAngle)
BICshort_l.setMaxContractionVelocity(10);
BICshort_l.setActivationTimeConstant(0.01);
BICshort_l.setDeactivationTimeConstant(0.04);
BICshort_l.setFmaxTendonStrain(0.033);
BICshort_l.setFmaxFiberStrain(0.6);
BICshort_l.setKshapeActive(0.5);
BICshort_l.setKshapePassive(4);
BICshort_l.setAf(0.3);
BICshort_l.setFlen(1.8);

% Path for BICshort_l
BICshort_l.addNewPathPoint('BICshort_l-P1', ground, ArrayDouble.createVec3([ 0.004675, -0.01231, -0.13475]));
BICshort_l.addNewPathPoint('BICshort_l-P2', ground, ArrayDouble.createVec3([-0.007075, -0.04004, -0.14507]));
BICshort_l.addNewPathPoint('BICshort_l-P3', humerus_l, ArrayDouble.createVec3([0.01117, -0.07576, 0.01101]));
BICshort_l.addNewPathPoint('BICshort_l-P4', humerus_l, ArrayDouble.createVec3([0.01703, -0.12125, 0.01079]));
BICshort_l.addNewPathPoint('BICshort_l-P5', humerus_l, ArrayDouble.createVec3([0.0228, -0.1754, 0.0063]));
BICshort_l.addNewPathPoint('BICshort_l-P6', ulna_l, ArrayDouble.createVec3([0.00751, -0.04839, -0.02179]));


model.addForce(BICshort_l)


% Set muscle parameters BRA_l
maxIsometricForce  = 987.26;
optimalFiberLength = 0.0858;
tendonSlackLength  = 0.0535;
pennationAngle 	   = 0;

% Create new muscle
BRA_l = Thelen2003Muscle();
BRA_l.setName('BRA_l')
BRA_l.setMaxIsometricForce(maxIsometricForce)
BRA_l.setOptimalFiberLength(optimalFiberLength)
BRA_l.setTendonSlackLength(tendonSlackLength);
BRA_l.setPennationAngleAtOptimalFiberLength(pennationAngle)
BRA_l.setMaxContractionVelocity(10);
BRA_l.setActivationTimeConstant(0.01);
BRA_l.setDeactivationTimeConstant(0.04);
BRA_l.setFmaxTendonStrain(0.033);
BRA_l.setFmaxFiberStrain(0.6);
BRA_l.setKshapeActive(0.5);
BRA_l.setKshapePassive(4);
BRA_l.setAf(0.3);
BRA_l.setFlen(1.8);

% Path for BRA_l
BRA_l.addNewPathPoint('BRA_l-P1', humerus_l, ArrayDouble.createVec3([0.0068, -0.1739, 0.0036]));
BRA_l.addNewPathPoint('BRA_l-P2', ulna_l, ArrayDouble.createVec3([-0.0032, -0.0239, -0.0009]));

%Create the Muscle Wrap Object
TRI_muscle_l=PathWrap();
TRI_muscle_l.setName('TRI_l');
TRI_muscle_l.setWrapObject(TRI_l);
geoPath=BRA_l.getGeometryPath();  %Get the muscles geometry
TRI_wrapSet_l=geoPath.getWrapSet();           %Get the muscle's wrap set
TRI_wrapSet_l.cloneAndAppend(TRI_muscle_l);   %Add the wrap created above to the muscles wrap set
 

model.addForce(BRA_l)

%% Marker set
marker_set=model.getMarkerSet; %create Marker Set

r_acromion = Marker(); %create a marker for the rigth shoulder 
r_acromion.setName('r_acromion'); % set marker name
r_acromion.changeBody(ground); %set body association
prop = r_acromion.getPropertyByName('location'); % use PropertyHelper to set marker location on body segment
x_location = PropertyHelper.getValueDouble(prop , 0); % set x location
PropertyHelper.setValueDouble(-0.01256,prop, 0); % set the value of x location
y_location = PropertyHelper.getValueDouble(prop , 1); % set y location
PropertyHelper.setValueDouble(0.04,prop, 1); % set the value of y location
z_location = PropertyHelper.getValueDouble(prop , 2); % set z location
PropertyHelper.setValueDouble(0.17,prop, 2); % set the value of z location
r_acromion.connectMarkerToModel(model); %connect the marker to the model

marker_set.cloneAndAppend(r_acromion); % append the new market to the marker set

r_humerus_epicondyle = Marker(); %create a marker for the rigth elbow
r_humerus_epicondyle.setName('r_humerus_epicondyle'); % set marker name
r_humerus_epicondyle.changeBody(humerus); %set body association
prop = r_humerus_epicondyle.getPropertyByName('location'); % use PropertyHelper to set marker location on body segment
x_location = PropertyHelper.getValueDouble(prop , 0); % set x location
PropertyHelper.setValueDouble(0.005,prop, 0); % set the value of x location
y_location = PropertyHelper.getValueDouble(prop , 1); % set y location
PropertyHelper.setValueDouble(-0.2904,prop, 1); % set the value of y location
z_location = PropertyHelper.getValueDouble(prop , 2); % set z location
PropertyHelper.setValueDouble(0.03,prop, 2);% set the value of z location
r_humerus_epicondyle.connectMarkerToModel(model); %connect the marker to the model

marker_set.cloneAndAppend(r_humerus_epicondyle); % append the new market to the marker set

r_radius_styloid = Marker(); %create a marker for the rigth wrist
r_radius_styloid.setName('r_radius_styloid');
r_radius_styloid.changeBody(ulna);
prop = r_radius_styloid.getPropertyByName('location');
x_location = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(-0.0011,prop, 0);
y_location = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.23559,prop, 1);
z_location = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(0.0943,prop, 2);
r_radius_styloid.connectMarkerToModel(model);
marker_set.cloneAndAppend(r_radius_styloid);

l_acromion = Marker(); %create a marker for the left shoulder
l_acromion.setName('l_acromion');
l_acromion.changeBody(ground);
prop = l_acromion.getPropertyByName('location');
x_location = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(-0.01256,prop, 0);
y_location = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(0.04,prop, 1);
z_location = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(-0.17,prop, 2);
l_acromion.connectMarkerToModel(model);
marker_set.cloneAndAppend(l_acromion);

l_humerus_epicondyle = Marker(); %create a marker for the left elbow
l_humerus_epicondyle.setName('l_humerus_epicondyle');
l_humerus_epicondyle.changeBody(humerus_l);
prop = l_humerus_epicondyle.getPropertyByName('location');
x_location = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(0.005,prop, 0);
y_location = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.2904,prop, 1);
z_location = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(-0.03,prop, 2);
l_humerus_epicondyle.connectMarkerToModel(model);
marker_set.cloneAndAppend(l_humerus_epicondyle);

l_radius_styloid = Marker(); %create a marker for the left wrist
l_radius_styloid.setName('l_radius_styloid');
l_radius_styloid.changeBody(ulna_l);
prop = l_radius_styloid.getPropertyByName('location');
x_location = PropertyHelper.getValueDouble(prop , 0);
PropertyHelper.setValueDouble(-0.0011,prop, 0);
y_location = PropertyHelper.getValueDouble(prop , 1);
PropertyHelper.setValueDouble(-0.23559,prop, 1);
z_location = PropertyHelper.getValueDouble(prop , 2);
PropertyHelper.setValueDouble(-0.0943,prop, 2);
l_radius_styloid.connectMarkerToModel(model);
marker_set.cloneAndAppend(l_radius_styloid);

%% salvare il modello .osim
model.print('amr26_bilaterale.osim');


